@@ -1,6 +1,6 @@
 /**************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                               */
-/*  Copyright (C) 2005 - 2007  Felipe Castro                              */
+/*  Copyright (C) 2005 - 2008  Felipe Castro                              */
 /*                                                                        */
 /*  This program is free software, licensed under the terms of the GNU    */
 /*  General Public License as published by the Free Software Foundation,  */
@@ -136,8 +136,7 @@ adapt_create_number (gunichar ucs4_word[MAX_WORD_LEN + 1])
 	if (rand () % 3)
 		snprintf (word, MAX_WORD_LEN + 1, "%i", rand () % 3101 - 999);
 	else
-		snprintf (word, MAX_WORD_LEN + 1, "%.2f",
-			  (rand () % 10000 - 2000) + (rand () % 100) / 100.0);
+		snprintf (word, MAX_WORD_LEN + 1, "%.2f", (rand () % 10000 - 2000) + (rand () % 100) / 100.0);
 	word[MAX_WORD_LEN] = '\0';
 
 	tmp_ucs4 = g_utf8_to_ucs4_fast (word, -1, &n);
@@ -152,7 +151,7 @@ adapt_create_number (gunichar ucs4_word[MAX_WORD_LEN + 1])
 void
 adapt_comment (gdouble accuracy)
 {
-	gchar str[1000];
+	gchar *tmp_str;
 	GtkWidget *wg;
 	GtkTextBuffer *buf;
 
@@ -160,33 +159,32 @@ adapt_comment (gdouble accuracy)
 	 * Comments
 	 */
 	if (accuracy < 50)
-		sprintf (str, _(" You must be kidding.\n"
-				" Your error rate is too high!\n"
-				" Please do it right.\n"));
+		tmp_str =
+			g_strdup (_
+				  (" You must be kidding.\n" " Your error rate is too high!\n"
+				   " Please do it right.\n"));
 
 	else if (accuracy < 90)
-		sprintf (str,
-			 _(" You are not ready to practice this exercise.\n"
-			   " Your accuracy rate is below 90 %%...\n"
-			   " Try to accomplish most of the basic course lessons.\n"));
+		tmp_str = g_strdup (_(" You are not ready to practice this exercise.\n"
+				      " Your accuracy rate is below 90 %%...\n"
+				      " Try to accomplish most of the basic course lessons.\n"));
 	else if (accuracy < 95)
-		sprintf (str,
-			 _(" You are doing well. But...\n"
-			   " Could you make the accuracy reach at least 95 %%?\n"));
+		tmp_str =
+			g_strdup (_
+				  (" You are doing well. But...\n"
+				   " Could you make the accuracy reach at least 95 %%?\n"));
 	else if (accuracy < 99)
-		sprintf (str,
-			 _(" You are almost there,"
-			   " but your accuracy rate is still below 99 %%.\n"
-			   " Try a few more times,"
-			   " so that I can evaluate your velocity.\n"));
+		tmp_str = g_strdup (_(" You are almost there,"
+				      " but your accuracy rate is still below 99 %%.\n"
+				      " Try a few more times," " so that I can evaluate your velocity.\n"));
 	else
-		sprintf (str,
-			 _(" Very good!\n"
-			   " You succeeded with an accuracy rate above 99 %%.\n"
-			   " Now it is time to increase your velocity.\n"
-			   " Go to the 3rd exercise at the main menu.\n"));
+		tmp_str = g_strdup (_(" Very good!\n"
+				      " You succeeded with an accuracy rate above 99 %%.\n"
+				      " Now it is time to increase your velocity.\n"
+				      " Go to the 3rd exercise at the main menu.\n"));
 
 	wg = lookup_widget (window_tutor_, "text_tutor");
 	buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (wg));
-	gtk_text_buffer_insert_at_cursor (buf, str, strlen (str));
+	gtk_text_buffer_insert_at_cursor (buf, tmp_str, strlen (tmp_str));
+	g_free (tmp_str);
 }
