@@ -1,6 +1,6 @@
 /**************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                               */
-/*  Copyright (C) 2005 - 2007  Felipe Castro                              */
+/*  Copyright (C) 2005 - 2008  Felipe Castro                              */
 /*                                                                        */
 /*  This program is free software, licensed under the terms of the GNU    */
 /*  General Public License as published by the Free Software Foundation,  */
@@ -34,6 +34,7 @@ struct
 	gint lesson;
 	gunichar char_set[MAX_BASIC_CHAR_SET];
 	glong char_set_size;
+	gboolean lesson_increased;
 } basic;
 
 /*******************************************************************************
@@ -59,6 +60,18 @@ basic_get_char_set ()
 	return (basic.char_set);
 }
 
+gboolean
+basic_get_lesson_increased ()
+{
+	return (basic.lesson_increased);
+}
+
+void
+basic_set_lesson_increased (gboolean state)
+{
+	basic.lesson_increased = state;
+}
+
 /*******************************************************************************
  * Initialize basic vars
  */
@@ -68,6 +81,7 @@ basic_init ()
 	/*
 	 * Retrieve the last lesson where the student had stopped.
 	 */
+	basic.lesson_increased = FALSE;
 	tutor_set_query (QUERY_INTRO);
 	if (basic.lesson != 0)
 	{
@@ -78,8 +92,7 @@ basic_init ()
 
 	if (main_preferences_exist ("tutor", "basic_lesson"))
 	{
-		basic.lesson =
-			main_preferences_get_int ("tutor", "basic_lesson");
+		basic.lesson = main_preferences_get_int ("tutor", "basic_lesson");
 		basic_init_char_set ();
 		tutor_process_touch ('\0');
 	}
@@ -88,10 +101,8 @@ basic_init ()
 		basic_set_lesson (1);
 		basic_init_char_set ();
 		tutor_update ();
-		gtk_widget_hide (lookup_widget
-				 (window_tutor_, "button_revert_lesson"));
-		gtk_widget_hide (lookup_widget
-				 (window_tutor_, "button_reset_lesson"));
+		gtk_widget_hide (lookup_widget (window_tutor_, "button_revert_lesson"));
+		gtk_widget_hide (lookup_widget (window_tutor_, "button_reset_lesson"));
 	}
 }
 
@@ -115,14 +126,10 @@ basic_init_char_set ()
 	wg = lookup_widget (window_tutor_, "togglebutton_edit_basic_lesson");
 	if (basic.lesson > 43 && basic.lesson <= 50)
 	{
-		lesson_file =
-			g_strdup_printf ("%sbasic_lesson_%i.txt",
-					 main_get_user_dir (), basic.lesson);
-		if (g_file_get_contents
-		    (lesson_file, &lesson_str, NULL, NULL))
+		lesson_file = g_strdup_printf ("%sbasic_lesson_%i.txt", main_get_user_dir (), basic.lesson);
+		if (g_file_get_contents (lesson_file, &lesson_str, NULL, NULL))
 		{
-			tmpuc = g_utf8_to_ucs4_fast (lesson_str, -1,
-						     &basic.char_set_size);
+			tmpuc = g_utf8_to_ucs4_fast (lesson_str, -1, &basic.char_set_size);
 			if (basic.char_set_size > MAX_BASIC_CHAR_SET)
 				basic.char_set_size = MAX_BASIC_CHAR_SET;
 			for (i = j = 0; i < basic.char_set_size; i++)
@@ -150,9 +157,7 @@ basic_init_char_set ()
 	/*
 	 * Open the lesson file
 	 */
-	lesson_file =
-		g_strconcat (main_get_data_path (), "basic_lessons.txt",
-			     NULL);
+	lesson_file = g_strconcat (main_get_data_path (), "basic_lessons.txt", NULL);
 	fh = (FILE *) g_fopen (lesson_file, "r");
 	g_free (lesson_file);
 	if (!fh)
@@ -191,11 +196,8 @@ basic_init_char_set ()
 		}
 		for (j = 0; j < 14; j++)
 		{
-			if (line_str[j] == '1'
-			    && g_unichar_isgraph (keyb_get_lochars (i, j)))
-				basic.char_set[k++] =
-					g_unichar_tolower (keyb_get_lochars
-							   (i, j));
+			if (line_str[j] == '1' && g_unichar_isgraph (keyb_get_lochars (i, j)))
+				basic.char_set[k++] = g_unichar_tolower (keyb_get_lochars (i, j));
 		}
 	}
 
@@ -223,11 +225,8 @@ basic_init_char_set ()
 			return (-1);
 		}
 		for (j = 0; j < 14; j++)
-			if (line_str[j] == '1'
-			    && g_unichar_isgraph (keyb_get_upchars (i, j)))
-				basic.char_set[k++] =
-					g_unichar_tolower (keyb_get_upchars
-							   (i, j));
+			if (line_str[j] == '1' && g_unichar_isgraph (keyb_get_upchars (i, j)))
+				basic.char_set[k++] = g_unichar_tolower (keyb_get_upchars (i, j));
 	}
 	fclose (fh);
 
@@ -246,9 +245,7 @@ basic_save_lesson (gchar * charset)
 	gchar *lesson_file;
 	FILE *fh;
 
-	lesson_file =
-		g_strdup_printf ("%sbasic_lesson_%i.txt",
-				 main_get_user_dir (), basic.lesson);
+	lesson_file = g_strdup_printf ("%sbasic_lesson_%i.txt", main_get_user_dir (), basic.lesson);
 	fh = (FILE *) g_fopen (lesson_file, "w");
 	if (fh == NULL)
 		g_warning ("couldn't save the file:\n %s", lesson_file);
@@ -292,8 +289,7 @@ basic_draw_lesson ()
 
 	for (k = 0; k < (N_LINES * 9 * 5 - len); k += len)
 	{
-		memmove (char_pool + k, basic.char_set,
-			 len * sizeof (gunichar));
+		memmove (char_pool + k, basic.char_set, len * sizeof (gunichar));
 	}
 	remain = (N_LINES * 9 * 5) % len;
 	remain = remain ? remain : len;
@@ -331,7 +327,7 @@ basic_draw_lesson ()
 void
 basic_comment (gdouble accuracy)
 {
-	gchar str[1000];
+	gchar *tmp_str;
 	GtkLabel *wg_label;
 	GtkWidget *wg;
 	GtkTextBuffer *buf;
@@ -340,38 +336,31 @@ basic_comment (gdouble accuracy)
 	 * Comments
 	 */
 	if (accuracy < 95.0)
-		sprintf (str,
-			 _(" You did not succeed.\n"
-			   " The accuracy must be above 95 %%.\n"
-			   " Try again!\n"));
+		tmp_str = g_strdup (_(" You did not succeed.\n The accuracy must be above 95 %%.\n Try again!\n"));
 	else
 	{
 		basic_set_lesson (basic.lesson + 1);
 		if (basic.lesson > 43)
 		{
 			if (basic.lesson > 50)
-				basic_set_lesson (1);
-			wg_label =
-				GTK_LABEL (lookup_widget
-					   (window_tutor_, "label_heading"));
-			gtk_label_set_text (wg_label,
-					    _
-					    ("Positions of keys seems to be learned!"));
-			sprintf (str,
-				 _(" Congratulations!\n"
-				   " You have accomplished the entire basic course.\n"
-				   " Go to the next type of exercise: adaptability.\n"
-				   " There you will practice mainly the accuracy.\n"));
+				basic_set_lesson (50);
+			wg_label = GTK_LABEL (lookup_widget (window_tutor_, "label_heading"));
+			gtk_label_set_text (wg_label, _("Positions of keys seems to be learned!"));
+			tmp_str = g_strdup (_(" Congratulations!\n"
+					      " You have accomplished the entire basic course.\n"
+					      " Go to the next type of exercise: adaptability.\n"
+					      " There you will practice mainly the accuracy.\n"));
 		}
 		else
-			sprintf (str,
-				 _(" All right, now you got it!\n"
-				   " Go to the next lesson.\n"));
+			tmp_str = g_strdup (_(" All right, now you got it!\n Go to the next lesson.\n"));
 
 		basic_init_char_set ();
+		if (basic.lesson != 50)
+			basic.lesson_increased = TRUE;
 	}
 
 	wg = lookup_widget (window_tutor_, "text_tutor");
 	buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (wg));
-	gtk_text_buffer_insert_at_cursor (buf, str, strlen (str));
+	gtk_text_buffer_insert_at_cursor (buf, tmp_str, strlen (tmp_str));
+	g_free (tmp_str);
 }
