@@ -1,6 +1,6 @@
 /**************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                               */
-/*  Copyright (C) 2005 - 2007  Felipe Castro                              */
+/*  Copyright (C) 2005 - 2008  Felipe Castro                              */
 /*                                                                        */
 /*  This program is free software, licensed under the terms of the GNU    */
 /*  General Public License as published by the Free Software Foundation,  */
@@ -16,6 +16,10 @@ void basic_set_lesson (gint lesson);
 
 gunichar *basic_get_char_set (void);
 
+gboolean basic_get_lesson_increased (void);
+
+void basic_set_lesson_increased (gboolean state);
+
 /*
  * Auxiliar functions
  */
