@@ -1,6 +1,6 @@
 /**************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                               */
-/*  Copyright (C) 2005 - 2007  Felipe Castro                              */
+/*  Copyright (C) 2005 - 2008  Felipe Castro                              */
 /*                                                                        */
 /*  This program is free software, licensed under the terms of the GNU    */
 /*  General Public License as published by the Free Software Foundation,  */
@@ -87,8 +87,7 @@ on_button_help_clicked (GtkButton * button, gpointer user_data)
 
 	wg_text = GTK_TEXT_VIEW (lookup_widget (dialog, "text_info"));
 	trans_read_text (text, TEXTMAXLEN, "_help.txt");
-	gtk_text_buffer_set_text (gtk_text_view_get_buffer (wg_text), text,
-				  -1);
+	gtk_text_buffer_set_text (gtk_text_view_get_buffer (wg_text), text, -1);
 
 	gtk_widget_show (dialog);
 	gtk_widget_hide (window_main_);
@@ -116,18 +115,15 @@ on_button_about_clicked (GtkButton * button, gpointer user_data)
 	trans_read_text (text, TEXTMAXLEN, "_about.txt");
 	text1 = strstr (text, "(V)");
 	if (text1 == NULL)
-		text1 = g_strconcat ("\n ", _("Version:"), " ",
-				     PACKAGE_VERSION, "\n", text, NULL);
+		text1 = g_strconcat ("\n ", _("Version:"), " ", PACKAGE_VERSION, "\n", text, NULL);
 	else
 	{
 		*text1 = '\0';
 		text1 += 3;
-		text1 = g_strconcat (text, _("Version:"), " ",
-				     PACKAGE_VERSION, text1, NULL);
+		text1 = g_strconcat (text, _("Version:"), " ", PACKAGE_VERSION, text1, NULL);
 	}
 
-	gtk_text_buffer_set_text (gtk_text_view_get_buffer (wg_text), text1,
-				  -1);
+	gtk_text_buffer_set_text (gtk_text_view_get_buffer (wg_text), text1, -1);
 	g_free (text1);
 
 	gtk_widget_show (dialog);
@@ -181,9 +177,7 @@ on_button_change_language_clicked (GtkButton * button, gpointer user_data)
 	GtkWidget *dialog_confirm;
 
 	dialog_confirm = create_dialog_confirm ();
-	gtk_label_set_text (GTK_LABEL (lookup_widget
-				       (dialog_confirm,
-					"label_confirm_action")), "CHANGE");
+	gtk_label_set_text (GTK_LABEL (lookup_widget (dialog_confirm, "label_confirm_action")), "CHANGE");
 	gtk_widget_show (dialog_confirm);
 }
 
@@ -205,8 +199,7 @@ on_button_intro_clicked (GtkButton * button, gpointer user_data)
 
 	wg_text = GTK_TEXT_VIEW (lookup_widget (dialog_intro, "text_info"));
 	trans_read_text (text, TEXTMAXLEN, "_intro.txt");
-	gtk_text_buffer_set_text (gtk_text_view_get_buffer (wg_text), text,
-				  -1);
+	gtk_text_buffer_set_text (gtk_text_view_get_buffer (wg_text), text, -1);
 
 	gtk_widget_show (dialog_intro);
 	gtk_widget_hide (window_main_);
@@ -283,8 +276,7 @@ on_dialog_info_destroy (GtkObject * object, gpointer user_data)
 
 
 void
-on_dialog_info_response (GtkDialog * dialog,
-			 gint response_id, gpointer user_data)
+on_dialog_info_response (GtkDialog * dialog, gint response_id, gpointer user_data)
 {
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
@@ -325,8 +317,7 @@ on_window_keyboard_destroy (GtkObject * object, gpointer user_data)
 
 
 gboolean
-on_window_keyboard_delete_event (GtkWidget * widget,
-				 GdkEvent * event, gpointer user_data)
+on_window_keyboard_delete_event (GtkWidget * widget, GdkEvent * event, gpointer user_data)
 {
 	gtk_widget_destroy (widget);
 	return FALSE;
@@ -338,9 +329,7 @@ on_window_keyboard_delete_event (GtkWidget * widget,
  */
 void
 on_entry_kb_main_insert_text (GtkEditable * editable,
-			      gchar * new_text,
-			      gint new_text_length,
-			      gpointer position, gpointer user_data)
+			      gchar * new_text, gint new_text_length, gpointer position, gpointer user_data)
 {
 	gchar *tmp_str;
 
@@ -362,9 +351,7 @@ on_entry_kb_main_insert_text (GtkEditable * editable,
  */
 void
 on_entry_kb_user_insert_text (GtkEditable * editable,
-			      gchar * new_text,
-			      gint new_text_length,
-			      gpointer position, gpointer user_data)
+			      gchar * new_text, gint new_text_length, gpointer position, gpointer user_data)
 {
 	gchar *tmp_str;
 
@@ -399,9 +386,7 @@ on_button_kb_save_clicked (GtkButton * button, gpointer user_data)
 		keyb_set_name (".tmp");
 	else
 	{
-		tmp_path =
-			g_strconcat (main_get_user_dir (), keyb_get_name (),
-				     ".kbd", NULL);
+		tmp_path = g_strconcat (main_get_user_dir (), keyb_get_name (), ".kbd", NULL);
 		fh = (FILE *) g_fopen (tmp_path, "r");
 		g_free (tmp_path);
 		if (fh)
@@ -409,9 +394,7 @@ on_button_kb_save_clicked (GtkButton * button, gpointer user_data)
 			fclose (fh);
 			dialog_confirm = create_dialog_confirm ();
 			gtk_label_set_text (GTK_LABEL (lookup_widget
-						       (dialog_confirm,
-							"label_confirm_action")),
-					    "OVERWRITE");
+						       (dialog_confirm, "label_confirm_action")), "OVERWRITE");
 			gtk_widget_show (dialog_confirm);
 			return;
 		}
@@ -449,10 +432,7 @@ on_button_kb_remove_clicked (GtkButton * button, gpointer user_data)
 	g_free (tmp_keyb);
 
 	dialog_confirm = create_dialog_confirm ();
-	gtk_label_set_text (GTK_LABEL
-			    (lookup_widget
-			     (dialog_confirm, "label_confirm_action")),
-			    "REMOVE");
+	gtk_label_set_text (GTK_LABEL (lookup_widget (dialog_confirm, "label_confirm_action")), "REMOVE");
 	gtk_widget_show (dialog_confirm);
 }
 
@@ -498,9 +478,7 @@ on_button_keyboard_cancel_clicked (GtkButton * button, gpointer user_data)
  * Allowing or not to select "load" tab on notebook
  */
 void
-on_notebook_kb_switch_page (GtkNotebook * notebook,
-			    GtkNotebookPage * page,
-			    guint page_num, gpointer user_data)
+on_notebook_kb_switch_page (GtkNotebook * notebook, GtkNotebookPage * page, guint page_num, gpointer user_data)
 {
 	if (keyb_get_modified_status () == FALSE)
 		return;
@@ -576,15 +554,12 @@ on_button_keyboard_close_clicked (GtkButton * button, gpointer user_data)
  */
 void
 on_entry_popup_key_insert_text (GtkEditable * editable,
-				gchar * new_text,
-				gint new_text_length,
-				gpointer position, gpointer user_data)
+				gchar * new_text, gint new_text_length, gpointer position, gpointer user_data)
 {
 	if (callbacks_shield)
 		return;
 
-	keyb_change_key (g_utf8_get_char_validated
-			 (new_text, new_text_length));
+	keyb_change_key (g_utf8_get_char_validated (new_text, new_text_length));
 	gtk_widget_hide (gtk_widget_get_toplevel (GTK_WIDGET (editable)));
 }
 
@@ -649,30 +624,24 @@ on_text_tutor_realize (GtkWidget * widget, gpointer user_data)
 	buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
 
 	gtk_text_buffer_create_tag (buf, "char_untouched",
-				    "background", TUTOR_GRAY_BLUE, NULL);
+				    "background", TUTOR_GRAY_BLUE, "foreground", TUTOR_BLACK, NULL);
 
-	gtk_text_buffer_create_tag (buf, "char_wrong",
-				    "background", TUTOR_RED, NULL);
+	gtk_text_buffer_create_tag (buf, "char_wrong", "background", TUTOR_RED, "foreground", TUTOR_BLACK, NULL);
 
-	gtk_text_buffer_create_tag (buf, "char_correct",
-				    "background", TUTOR_GREEN, NULL);
+	gtk_text_buffer_create_tag (buf, "char_correct", "background", TUTOR_GREEN, "foreground", TUTOR_BLACK, NULL);
 
 	gtk_text_buffer_create_tag (buf, "char_retouched",
-				    "background", TUTOR_YELLOW_GREEN, NULL);
+				    "background", TUTOR_YELLOW_GREEN, "foreground", TUTOR_BLACK, NULL);
 
-	gtk_text_buffer_create_tag (buf, "cursor_blink",
-				    "background", TUTOR_BLACK,
-				    "foreground", TUTOR_WHITE, NULL);
+	gtk_text_buffer_create_tag (buf, "cursor_blink", "background", TUTOR_BLACK, "foreground", TUTOR_WHITE, NULL);
 
 	tmp_font = main_preferences_get_string ("tutor", "lesson_font");
 	if (tmp_font == NULL)
 	{
 		tmp_font = g_strdup (LESSON_FONT);
-		main_preferences_set_string ("tutor", "lesson_font",
-					     tmp_font);
+		main_preferences_set_string ("tutor", "lesson_font", tmp_font);
 	}
-	gtk_text_buffer_create_tag (buf, "lesson_font", "font", tmp_font,
-				    NULL);
+	gtk_text_buffer_create_tag (buf, "lesson_font", "font", tmp_font, NULL);
 	g_free (tmp_font);
 
 	/* Change default font throughout the widget */
@@ -705,8 +674,7 @@ on_text_tutor_realize (GtkWidget * widget, gpointer user_data)
  * Selecting the basic course lessons
  */
 void
-on_spinbutton_lesson_value_changed (GtkSpinButton * spinbutton,
-				    gpointer user_data)
+on_spinbutton_lesson_value_changed (GtkSpinButton * spinbutton, gpointer user_data)
 {
 	gint tmp_int;
 
@@ -716,16 +684,14 @@ on_spinbutton_lesson_value_changed (GtkSpinButton * spinbutton,
 	if (tutor_get_type () == TT_BASIC)
 	{
 		tmp_int = main_preferences_get_int ("tutor", "basic_lesson");
-		basic_set_lesson (gtk_spin_button_get_value_as_int
-				  (spinbutton));
+		basic_set_lesson (gtk_spin_button_get_value_as_int (spinbutton));
 		main_preferences_set_int ("tutor", "basic_lesson", tmp_int);
 		basic_init_char_set ();
 	}
 	else if (tutor_get_type () == TT_FLUID)
 	{
 		tmp_int = gtk_spin_button_get_value_as_int (spinbutton);
-		main_preferences_set_int ("tutor", "fluid_paragraphs",
-					  tmp_int);
+		main_preferences_set_int ("tutor", "fluid_paragraphs", tmp_int);
 	}
 	tutor_set_query (QUERY_INTRO);
 	tutor_process_touch (L'\0');
@@ -756,10 +722,7 @@ on_button_reset_lesson_clicked (GtkButton * button, gpointer user_data)
 	GtkWidget *dialog_confirm;
 
 	dialog_confirm = create_dialog_confirm ();
-	gtk_label_set_text (GTK_LABEL
-			    (lookup_widget
-			     (dialog_confirm, "label_confirm_action")),
-			    "RESET");
+	gtk_label_set_text (GTK_LABEL (lookup_widget (dialog_confirm, "label_confirm_action")), "RESET");
 	gtk_widget_show (dialog_confirm);
 }
 
@@ -791,10 +754,8 @@ on_button_tutor_stat_clicked (GtkButton * button, gpointer user_data)
 	{
 	case TT_BASIC:
 		gtk_label_set_text (label_stat, _("basic course"));
-		gtk_widget_show (lookup_widget
-				 (window_stat_, "label_stat_lesson"));
-		gtk_widget_show (lookup_widget
-				 (window_stat_, "label_stat_lesson_n"));
+		gtk_widget_show (lookup_widget (window_stat_, "label_stat_lesson"));
+		gtk_widget_show (lookup_widget (window_stat_, "label_stat_lesson_n"));
 		break;
 	case TT_ADAPT:
 		gtk_label_set_text (label_stat, _("adaptability exercises"));
@@ -804,8 +765,7 @@ on_button_tutor_stat_clicked (GtkButton * button, gpointer user_data)
 		break;
 	case TT_FLUID:
 		gtk_label_set_text (label_stat, _("fluidness exercises"));
-		gtk_widget_show (lookup_widget
-				 (window_stat_, "toggle_stat_fluid"));
+		gtk_widget_show (lookup_widget (window_stat_, "toggle_stat_fluid"));
 	}
 
 	gtk_widget_show (window_stat_);
@@ -824,14 +784,11 @@ on_button_tutor_show_keyb_clicked (GtkButton * button, gpointer user_data)
 	window_keyboard_ = create_window_keyboard ();
 	gtk_widget_show (lookup_widget (window_keyboard_, "hbox_kb_tutor"));
 	gtk_widget_hide (lookup_widget (window_keyboard_, "vbox_kb_left"));
-	gtk_widget_set_sensitive (lookup_widget
-				  (window_keyboard_, "but_space"), TRUE);
-	gtk_window_set_title (GTK_WINDOW (window_keyboard_),
-			      _("Virtual Keyboard"));
+	gtk_widget_set_sensitive (lookup_widget (window_keyboard_, "but_space"), TRUE);
+	gtk_window_set_title (GTK_WINDOW (window_keyboard_), _("Virtual Keyboard"));
 	gtk_label_set_text (GTK_LABEL
 			    (lookup_widget
-			     (window_keyboard_, "label_virtual_kb")),
-			    _("Relation between the fingers and the keys"));
+			     (window_keyboard_, "label_virtual_kb")), _("Relation between the fingers and the keys"));
 
 	keyb_update_virtual_layout ();
 	hints_init ();
@@ -863,8 +820,8 @@ on_button_tutor_close_clicked (GtkButton * button, gpointer user_data)
 /*******************************************************************************
  * Editing a custom basic lesson
  */
-void on_togglebutton_edit_basic_lesson_toggled
-	(GtkToggleButton * togglebutton, gpointer user_data)
+void
+on_togglebutton_edit_basic_lesson_toggled (GtkToggleButton * togglebutton, gpointer user_data)
 {
 	gchar *tmp_name;
 	GtkWidget *wg;
@@ -876,9 +833,7 @@ void on_togglebutton_edit_basic_lesson_toggled
 		gtk_widget_show (wg);
 		gtk_widget_grab_focus (wg);
 
-		tmp_name =
-			g_ucs4_to_utf8 (basic_get_char_set (), -1, NULL, NULL,
-					NULL);
+		tmp_name = g_ucs4_to_utf8 (basic_get_char_set (), -1, NULL, NULL, NULL);
 		gtk_entry_set_text (GTK_ENTRY (wg), g_strstrip (tmp_name));
 		gtk_entry_set_position (GTK_ENTRY (wg), -1);
 		g_free (tmp_name);
@@ -905,14 +860,11 @@ void on_togglebutton_edit_basic_lesson_toggled
 			tutor_set_query (QUERY_INTRO);
 			tutor_process_touch (L'\0');
 
-			wg = lookup_widget (window_tutor_,
-					    "spinbutton_lesson");
+			wg = lookup_widget (window_tutor_, "spinbutton_lesson");
 			gtk_widget_set_sensitive (wg, TRUE);
-			wg = lookup_widget (window_tutor_,
-					    "button_revert_lesson");
+			wg = lookup_widget (window_tutor_, "button_revert_lesson");
 			gtk_widget_set_sensitive (wg, TRUE);
-			wg = lookup_widget (window_tutor_,
-					    "button_reset_lesson");
+			wg = lookup_widget (window_tutor_, "button_reset_lesson");
 			gtk_widget_set_sensitive (wg, TRUE);
 		}
 		g_free (tmp_name);
@@ -942,15 +894,13 @@ void
 on_button_tutor_font_clicked (GtkButton * button, gpointer user_data)
 {
 	if (fontselectiondialog_tutor == NULL)
-		fontselectiondialog_tutor =
-			create_fontselectiondialog_tutor ();
+		fontselectiondialog_tutor = create_fontselectiondialog_tutor ();
 
 	gtk_widget_show (fontselectiondialog_tutor);
 }
 
 void
-on_fontselectiondialog_tutor_response (GtkDialog * dialog,
-				       gint response_id, gpointer user_data)
+on_fontselectiondialog_tutor_response (GtkDialog * dialog, gint response_id, gpointer user_data)
 {
 	GtkWidget *wg;
 	GtkTextBuffer *buf;
@@ -960,30 +910,23 @@ on_fontselectiondialog_tutor_response (GtkDialog * dialog,
 	gchar *tmp_font;
 
 	if (response_id == GTK_RESPONSE_CANCEL)
-		tmp_font =
-			main_preferences_get_string ("tutor", "lesson_font");
+		tmp_font = main_preferences_get_string ("tutor", "lesson_font");
 	else
-		tmp_font =
-			g_strdup (gtk_font_selection_dialog_get_font_name
-				  (GTK_FONT_SELECTION_DIALOG (dialog)));
+		tmp_font = g_strdup (gtk_font_selection_dialog_get_font_name (GTK_FONT_SELECTION_DIALOG (dialog)));
 
 	if (tmp_font == NULL)
 		tmp_font = g_strdup (LESSON_FONT);
 
 	if (response_id == GTK_RESPONSE_OK)
-		main_preferences_set_string ("tutor", "lesson_font",
-					     tmp_font);
+		main_preferences_set_string ("tutor", "lesson_font", tmp_font);
 
 	wg = lookup_widget (window_tutor_, "text_tutor");
 	buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (wg));
 	ttab = gtk_text_buffer_get_tag_table (buf);
 	gtk_text_buffer_get_bounds (buf, &start, &end);
 
-	gtk_text_tag_table_remove (ttab,
-				   gtk_text_tag_table_lookup (ttab,
-							      "lesson_font"));
-	gtk_text_buffer_create_tag (buf, "lesson_font", "font", tmp_font,
-				    NULL);
+	gtk_text_tag_table_remove (ttab, gtk_text_tag_table_lookup (ttab, "lesson_font"));
+	gtk_text_buffer_create_tag (buf, "lesson_font", "font", tmp_font, NULL);
 	gtk_text_buffer_apply_tag_by_name (buf, "lesson_font", &start, &end);
 
 	g_free (tmp_font);
@@ -995,8 +938,7 @@ on_fontselectiondialog_tutor_response (GtkDialog * dialog,
 void
 on_fontselectiondialog_tutor_destroy (GtkObject * object, gpointer user_data)
 {
-	on_fontselectiondialog_tutor_response (GTK_DIALOG (object),
-					       GTK_RESPONSE_CANCEL, NULL);
+	on_fontselectiondialog_tutor_response (GTK_DIALOG (object), GTK_RESPONSE_CANCEL, NULL);
 	fontselectiondialog_tutor = NULL;
 }
 
@@ -1005,8 +947,7 @@ on_fontselectiondialog_tutor_destroy (GtkObject * object, gpointer user_data)
  * Enabling sound or not
  */
 void
-on_checkbutton_beep_toggled (GtkToggleButton * togglebutton,
-			     gpointer user_data)
+on_checkbutton_beep_toggled (GtkToggleButton * togglebutton, gpointer user_data)
 {
 	gboolean beep;
 
@@ -1019,8 +960,7 @@ on_checkbutton_beep_toggled (GtkToggleButton * togglebutton,
  * Managing the keyboard/messages entry of the tutor window
  */
 gboolean
-on_entry_mesg_focus_out_event (GtkWidget * widget,
-			       GdkEventFocus * event, gpointer user_data)
+on_entry_mesg_focus_out_event (GtkWidget * widget, GdkEventFocus * event, gpointer user_data)
 {
 	if (callbacks_shield)
 		return (FALSE);
@@ -1065,8 +1005,7 @@ on_entry_mesg_activate (GtkEntry * entry, gpointer user_data)
 
 
 void
-on_entry_mesg_delete_text (GtkEditable * editable,
-			   gint start_pos, gint end_pos, gpointer user_data)
+on_entry_mesg_delete_text (GtkEditable * editable, gint start_pos, gint end_pos, gpointer user_data)
 {
 	if (callbacks_shield)
 		return;
@@ -1080,15 +1019,12 @@ on_entry_mesg_delete_text (GtkEditable * editable,
 
 void
 on_entry_mesg_insert_text (GtkEditable * editable,
-			   gchar * new_text,
-			   gint new_text_length,
-			   gpointer position, gpointer user_data)
+			   gchar * new_text, gint new_text_length, gpointer position, gpointer user_data)
 {
 	if (callbacks_shield)
 		return;
 
-	tutor_process_touch (g_utf8_get_char_validated
-			     (new_text, new_text_length));
+	tutor_process_touch (g_utf8_get_char_validated (new_text, new_text_length));
 }
 
 
@@ -1115,9 +1051,7 @@ on_button_tutor_restart_clicked (GtkButton * button, gpointer user_data)
  * Popup management
  */
 gboolean
-on_popup_other_enter_notify_event (GtkWidget * widget,
-				   GdkEventCrossing * event,
-				   gpointer user_data)
+on_popup_other_enter_notify_event (GtkWidget * widget, GdkEventCrossing * event, gpointer user_data)
 {
 	if (callbacks_shield)
 	{
@@ -1131,9 +1065,7 @@ on_popup_other_enter_notify_event (GtkWidget * widget,
 
 
 gboolean
-on_popup_other_leave_notify_event (GtkWidget * widget,
-				   GdkEventCrossing * event,
-				   gpointer user_data)
+on_popup_other_leave_notify_event (GtkWidget * widget, GdkEventCrossing * event, gpointer user_data)
 {
 	if (callbacks_shield)
 		return FALSE;
@@ -1156,13 +1088,10 @@ on_treeview_other_realize (GtkWidget * widget, gpointer user_data)
 	else if (tutor_get_type () == TT_FLUID)
 		tutor_load_list_other (".paragraphs", list);
 
-	gtk_tree_view_set_model (GTK_TREE_VIEW (widget),
-				 GTK_TREE_MODEL (list));
+	gtk_tree_view_set_model (GTK_TREE_VIEW (widget), GTK_TREE_MODEL (list));
 
 	renderer = gtk_cell_renderer_text_new ();
-	column = gtk_tree_view_column_new_with_attributes (":-)",
-							   renderer, "text",
-							   0, NULL);
+	column = gtk_tree_view_column_new_with_attributes (":-)", renderer, "text", 0, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (widget), column);
 }
 
@@ -1257,8 +1186,7 @@ on_button_other_remove_clicked (GtkButton * button, gpointer user_data)
  * Use chosen file to create a new exercise
  */
 void
-on_filechooser_tutor_response (GtkDialog * dialog,
-			       gint response_id, gpointer user_data)
+on_filechooser_tutor_response (GtkDialog * dialog, gint response_id, gpointer user_data)
 {
 	gchar *tmp_path;
 
@@ -1304,28 +1232,24 @@ on_frame_stat_realize (GtkWidget * widget, gpointer user_data)
  * Show accuracy chart
  */
 void
-on_toggle_stat_accur_toggled (GtkToggleButton * togglebutton,
-			      gpointer user_data)
+on_toggle_stat_accur_toggled (GtkToggleButton * togglebutton, gpointer user_data)
 {
 	GtkWidget *wg;
 
 	wg = lookup_widget (GTK_WIDGET (togglebutton), "toggle_stat_velo");
 	if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (wg)))
 	{
-		wg = lookup_widget (GTK_WIDGET (togglebutton),
-				    "toggle_stat_fluid");
+		wg = lookup_widget (GTK_WIDGET (togglebutton), "toggle_stat_fluid");
 		if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (wg)))
 		{
 			if (!gtk_toggle_button_get_active (togglebutton))
-				gtk_toggle_button_set_active (togglebutton,
-							      TRUE);
+				gtk_toggle_button_set_active (togglebutton, TRUE);
 			return;
 		}
 		else if (!gtk_toggle_button_get_active (togglebutton))
 			return;
 		else
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wg),
-						      FALSE);
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wg), FALSE);
 	}
 	else if (!gtk_toggle_button_get_active (togglebutton))
 		return;
@@ -1340,28 +1264,24 @@ on_toggle_stat_accur_toggled (GtkToggleButton * togglebutton,
  * Show velocity chart
  */
 void
-on_toggle_stat_velo_toggled (GtkToggleButton * togglebutton,
-			     gpointer user_data)
+on_toggle_stat_velo_toggled (GtkToggleButton * togglebutton, gpointer user_data)
 {
 	GtkWidget *wg;
 
 	wg = lookup_widget (GTK_WIDGET (togglebutton), "toggle_stat_accur");
 	if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (wg)))
 	{
-		wg = lookup_widget (GTK_WIDGET (togglebutton),
-				    "toggle_stat_fluid");
+		wg = lookup_widget (GTK_WIDGET (togglebutton), "toggle_stat_fluid");
 		if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (wg)))
 		{
 			if (!gtk_toggle_button_get_active (togglebutton))
-				gtk_toggle_button_set_active (togglebutton,
-							      TRUE);
+				gtk_toggle_button_set_active (togglebutton, TRUE);
 			return;
 		}
 		else if (!gtk_toggle_button_get_active (togglebutton))
 			return;
 		else
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wg),
-						      FALSE);
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wg), FALSE);
 	}
 	else if (!gtk_toggle_button_get_active (togglebutton))
 		return;
@@ -1376,28 +1296,24 @@ on_toggle_stat_velo_toggled (GtkToggleButton * togglebutton,
  * Show fluidness chart
  */
 void
-on_toggle_stat_fluid_toggled (GtkToggleButton * togglebutton,
-			      gpointer user_data)
+on_toggle_stat_fluid_toggled (GtkToggleButton * togglebutton, gpointer user_data)
 {
 	GtkWidget *wg;
 
 	wg = lookup_widget (GTK_WIDGET (togglebutton), "toggle_stat_accur");
 	if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (wg)))
 	{
-		wg = lookup_widget (GTK_WIDGET (togglebutton),
-				    "toggle_stat_velo");
+		wg = lookup_widget (GTK_WIDGET (togglebutton), "toggle_stat_velo");
 		if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (wg)))
 		{
 			if (!gtk_toggle_button_get_active (togglebutton))
-				gtk_toggle_button_set_active (togglebutton,
-							      TRUE);
+				gtk_toggle_button_set_active (togglebutton, TRUE);
 			return;
 		}
 		else if (!gtk_toggle_button_get_active (togglebutton))
 			return;
 		else
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wg),
-						      FALSE);
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wg), FALSE);
 	}
 	else if (!gtk_toggle_button_get_active (togglebutton))
 		return;
@@ -1438,20 +1354,14 @@ on_dialog_confirm_realize (GtkWidget * widget, gpointer user_data)
 
 	else if (strcmp (action, "OVERWRITE") == 0)
 	{
-		gtk_window_set_title (GTK_WINDOW (widget),
-				      _("Overwrite user layout"));
-		gtk_label_set_text (wg_label,
-				    _
-				    ("This will OVERWRITE an existent keyboard layout."));
+		gtk_window_set_title (GTK_WINDOW (widget), _("Overwrite user layout"));
+		gtk_label_set_text (wg_label, _("This will OVERWRITE an existent keyboard layout."));
 	}
 
 	else if (strcmp (action, "REMOVE") == 0)
 	{
-		gtk_window_set_title (GTK_WINDOW (widget),
-				      _("Remove user layout"));
-		gtk_label_set_text (wg_label,
-				    _
-				    ("This will REMOVE an existent keyboard layout."));
+		gtk_window_set_title (GTK_WINDOW (widget), _("Remove user layout"));
+		gtk_label_set_text (wg_label, _("This will REMOVE an existent keyboard layout."));
 	}
 
 	else if (strcmp (action, "RESET") == 0)
@@ -1466,8 +1376,7 @@ on_dialog_confirm_realize (GtkWidget * widget, gpointer user_data)
 
 	else
 	{
-		g_warning ("No valid action for this confirm-dialog: %s",
-			   action);
+		g_warning ("No valid action for this confirm-dialog: %s", action);
 		gtk_widget_destroy (widget);
 	}
 
@@ -1503,9 +1412,7 @@ on_button_confirm_yes_clicked (GtkButton * button, gpointer user_data)
 	}
 
 	else
-		g_warning
-			("No valid action selected for 'yes' confirm-button: %s",
-			 action);
+		g_warning ("No valid action selected for 'yes' confirm-button: %s", action);
 
 	gtk_widget_destroy (gtk_widget_get_toplevel (GTK_WIDGET (button)));
 }
