@@ -1,6 +1,6 @@
 /**************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                               */
-/*  Copyright (C) 2005 - 2007  Felipe Castro                              */
+/*  Copyright (C) 2005 - 2008  Felipe Castro                              */
 /*                                                                        */
 /*  This program is free software, licensed under the terms of the GNU    */
 /*  General Public License as published by the Free Software Foundation,  */
@@ -21,8 +21,7 @@ void on_button_exit_clicked (GtkButton * button, gpointer user_data);
 
 void on_button_keyboard_clicked (GtkButton * button, gpointer user_data);
 
-void
-on_button_change_language_clicked (GtkButton * button, gpointer user_data);
+void on_button_change_language_clicked (GtkButton * button, gpointer user_data);
 
 void on_button_intro_clicked (GtkButton * button, gpointer user_data);
 
@@ -39,59 +38,41 @@ void on_text_info_realize (GtkWidget * widget, gpointer user_data);
 
 void on_dialog_info_destroy (GtkObject * object, gpointer user_data);
 
-void
-on_dialog_info_response (GtkDialog * dialog,
-			 gint response_id, gpointer user_data);
+void on_dialog_info_response (GtkDialog * dialog, gint response_id, gpointer user_data);
 
 void on_window_keyboard_destroy (GtkObject * object, gpointer user_data);
 
-gboolean
-on_window_keyboard_delete_event (GtkWidget * widget,
-				 GdkEvent * event, gpointer user_data);
+gboolean on_window_keyboard_delete_event (GtkWidget * widget, GdkEvent * event, gpointer user_data);
 
 void
 on_entry_kb_main_insert_text (GtkEditable * editable,
-			      gchar * new_text,
-			      gint new_text_length,
-			      gpointer position, gpointer user_data);
+			      gchar * new_text, gint new_text_length, gpointer position, gpointer user_data);
 
 void
 on_entry_kb_user_insert_text (GtkEditable * editable,
-			      gchar * new_text,
-			      gint new_text_length,
-			      gpointer position, gpointer user_data);
+			      gchar * new_text, gint new_text_length, gpointer position, gpointer user_data);
 
 void on_button_kb_save_clicked (GtkButton * button, gpointer user_data);
 
 void on_button_kb_remove_clicked (GtkButton * button, gpointer user_data);
 
-void
-on_button_keyboard_select_clicked (GtkButton * button, gpointer user_data);
+void on_button_keyboard_select_clicked (GtkButton * button, gpointer user_data);
 
-void
-on_button_keyboard_cancel_clicked (GtkButton * button, gpointer user_data);
+void on_button_keyboard_cancel_clicked (GtkButton * button, gpointer user_data);
 
-void
-on_notebook_kb_switch_page (GtkNotebook * notebook,
-			    GtkNotebookPage * page,
-			    guint page_num, gpointer user_data);
+void on_notebook_kb_switch_page (GtkNotebook * notebook, GtkNotebookPage * page, guint page_num, gpointer user_data);
 
-void
-on_toggle_shift1_toggled (GtkToggleButton * togglebutton, gpointer user_data);
+void on_toggle_shift1_toggled (GtkToggleButton * togglebutton, gpointer user_data);
 
-void
-on_toggle_shift2_toggled (GtkToggleButton * togglebutton, gpointer user_data);
+void on_toggle_shift2_toggled (GtkToggleButton * togglebutton, gpointer user_data);
 
 void on_virtual_key_clicked (GtkButton * button, gpointer user_data);
 
-void
-on_button_keyboard_close_clicked (GtkButton * button, gpointer user_data);
+void on_button_keyboard_close_clicked (GtkButton * button, gpointer user_data);
 
 void
 on_entry_popup_key_insert_text (GtkEditable * editable,
-				gchar * new_text,
-				gint new_text_length,
-				gpointer position, gpointer user_data);
+				gchar * new_text, gint new_text_length, gpointer position, gpointer user_data);
 
 void on_button_popup_cancel_clicked (GtkButton * button, gpointer user_data);
 
@@ -101,9 +82,7 @@ void on_window_tutor_destroy (GtkObject * object, gpointer user_data);
 
 void on_text_tutor_realize (GtkWidget * widget, gpointer user_data);
 
-void
-on_spinbutton_lesson_value_changed (GtkSpinButton * spinbutton,
-				    gpointer user_data);
+void on_spinbutton_lesson_value_changed (GtkSpinButton * spinbutton, gpointer user_data);
 
 void on_button_revert_lesson_clicked (GtkButton * button, gpointer user_data);
 
@@ -113,8 +92,7 @@ void on_button_tutor_other_clicked (GtkButton * button, gpointer user_data);
 
 void on_button_tutor_stat_clicked (GtkButton * button, gpointer user_data);
 
-void
-on_button_tutor_show_keyb_clicked (GtkButton * button, gpointer user_data);
+void on_button_tutor_show_keyb_clicked (GtkButton * button, gpointer user_data);
 
 void on_button_tutor_intro_clicked (GtkButton * button, gpointer user_data);
 
@@ -122,45 +100,29 @@ void on_button_tutor_close_clicked (GtkButton * button, gpointer user_data);
 
 void on_button_tutor_font_clicked (GtkButton * button, gpointer user_data);
 
-void on_togglebutton_edit_basic_lesson_toggled
-	(GtkToggleButton * togglebutton, gpointer user_data);
+void on_togglebutton_edit_basic_lesson_toggled (GtkToggleButton * togglebutton, gpointer user_data);
 
-void
-on_entry_custom_basic_lesson_activate (GtkEntry * entry, gpointer user_data);
+void on_entry_custom_basic_lesson_activate (GtkEntry * entry, gpointer user_data);
 
-void
-on_checkbutton_beep_toggled (GtkToggleButton * togglebutton,
-			     gpointer user_data);
+void on_checkbutton_beep_toggled (GtkToggleButton * togglebutton, gpointer user_data);
 
-gboolean
-on_entry_mesg_focus_out_event (GtkWidget * widget,
-			       GdkEventFocus * event, gpointer user_data);
+gboolean on_entry_mesg_focus_out_event (GtkWidget * widget, GdkEventFocus * event, gpointer user_data);
 
 void on_entry_mesg_grab_focus (GtkWidget * widget, gpointer user_data);
 
 void on_entry_mesg_activate (GtkEntry * entry, gpointer user_data);
 
-void
-on_entry_mesg_delete_text (GtkEditable * editable,
-			   gint start_pos, gint end_pos, gpointer user_data);
+void on_entry_mesg_delete_text (GtkEditable * editable, gint start_pos, gint end_pos, gpointer user_data);
 
 void
 on_entry_mesg_insert_text (GtkEditable * editable,
-			   gchar * new_text,
-			   gint new_text_length,
-			   gpointer position, gpointer user_data);
+			   gchar * new_text, gint new_text_length, gpointer position, gpointer user_data);
 
 void on_button_tutor_restart_clicked (GtkButton * button, gpointer user_data);
 
-gboolean
-on_popup_other_enter_notify_event (GtkWidget * widget,
-				   GdkEventCrossing * event,
-				   gpointer user_data);
+gboolean on_popup_other_enter_notify_event (GtkWidget * widget, GdkEventCrossing * event, gpointer user_data);
 
-gboolean
-on_popup_other_leave_notify_event (GtkWidget * widget,
-				   GdkEventCrossing * event,
-				   gpointer user_data);
+gboolean on_popup_other_leave_notify_event (GtkWidget * widget, GdkEventCrossing * event, gpointer user_data);
 
 void on_treeview_other_realize (GtkWidget * widget, gpointer user_data);
 
@@ -172,25 +134,17 @@ void on_button_other_new_clicked (GtkButton * button, gpointer user_data);
 
 void on_button_other_remove_clicked (GtkButton * button, gpointer user_data);
 
-void
-on_filechooser_tutor_response (GtkDialog * dialog,
-			       gint response_id, gpointer user_data);
+void on_filechooser_tutor_response (GtkDialog * dialog, gint response_id, gpointer user_data);
 
 void on_filechooser_tutor_destroy (GtkObject * object, gpointer user_data);
 
 void on_frame_stat_realize (GtkWidget * widget, gpointer user_data);
 
-void
-on_toggle_stat_accur_toggled (GtkToggleButton * togglebutton,
-			      gpointer user_data);
+void on_toggle_stat_accur_toggled (GtkToggleButton * togglebutton, gpointer user_data);
 
-void
-on_toggle_stat_velo_toggled (GtkToggleButton * togglebutton,
-			     gpointer user_data);
+void on_toggle_stat_velo_toggled (GtkToggleButton * togglebutton, gpointer user_data);
 
-void
-on_toggle_stat_fluid_toggled (GtkToggleButton * togglebutton,
-			      gpointer user_data);
+void on_toggle_stat_fluid_toggled (GtkToggleButton * togglebutton, gpointer user_data);
 
 void on_button_stat_close_clicked (GtkButton * button, gpointer user_data);
 
@@ -204,9 +158,6 @@ void on_window_hints_destroy (GtkObject * object, gpointer user_data);
 
 
 
-void
-on_fontselectiondialog_tutor_response (GtkDialog * dialog,
-				       gint response_id, gpointer user_data);
+void on_fontselectiondialog_tutor_response (GtkDialog * dialog, gint response_id, gpointer user_data);
 
-void
-on_fontselectiondialog_tutor_destroy (GtkObject * object, gpointer user_data);
+void on_fontselectiondialog_tutor_destroy (GtkObject * object, gpointer user_data);
