@@ -1,6 +1,6 @@
 /**************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                               */
-/*  Copyright (C) 2005 - 2007  Felipe Castro                              */
+/*  Copyright (C) 2005 - 2008  Felipe Castro                              */
 /*                                                                        */
 /*  This program is free software, licensed under the terms of the GNU    */
 /*  General Public License as published by the Free Software Foundation,  */
@@ -69,55 +69,35 @@ cursor_advance (gint n)
 	wg = lookup_widget (window_tutor_, "text_tutor");
 	buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (wg));
 
-	gtk_text_buffer_get_iter_at_mark (buf, &new_start,
-					  gtk_text_buffer_get_insert (buf));
+	gtk_text_buffer_get_iter_at_mark (buf, &new_start, gtk_text_buffer_get_insert (buf));
 	old_start = new_start;
 
 	if (n > 0)
-		for (i = 0;
-		     i < n
-		     && gtk_text_iter_forward_cursor_position (&new_start);
-		     i++);
+		for (i = 0; i < n && gtk_text_iter_forward_cursor_position (&new_start); i++);
 	else
-		for (i = 0;
-		     i > n
-		     && gtk_text_iter_backward_cursor_position (&new_start);
-		     i--);
+		for (i = 0; i > n && gtk_text_iter_backward_cursor_position (&new_start); i--);
 
 	end = new_start;
 	gtk_text_iter_forward_char (&end);
-	gtk_text_buffer_apply_tag_by_name (buf, "cursor_blink", &new_start,
-					   &end);
+	gtk_text_buffer_apply_tag_by_name (buf, "cursor_blink", &new_start, &end);
 
 	end = old_start;
 	gtk_text_iter_forward_char (&end);
-	gtk_text_buffer_remove_tag_by_name (buf, "cursor_blink", &old_start,
-					    &end);
+	gtk_text_buffer_remove_tag_by_name (buf, "cursor_blink", &old_start, &end);
 
 	gtk_text_buffer_place_cursor (buf, &new_start);
 
 	if (i == n)
 	{
-		mark = gtk_text_buffer_create_mark (buf, "aux", &new_start,
-						    FALSE);
-		cursor_out_screen =
-			gtk_text_view_move_mark_onscreen (GTK_TEXT_VIEW (wg),
-							  mark);
+		mark = gtk_text_buffer_create_mark (buf, "aux", &new_start, FALSE);
+		cursor_out_screen = gtk_text_view_move_mark_onscreen (GTK_TEXT_VIEW (wg), mark);
 		if (cursor_out_screen)
 		{
-			gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW
-							    (wg),
-							    gtk_text_buffer_get_insert
-							    (buf));
-			wg = lookup_widget (window_tutor_,
-					    "scrolledwindow_tutor_main");
-			scroll = gtk_scrolled_window_get_vadjustment
-				(GTK_SCROLLED_WINDOW (wg));
+			gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (wg), gtk_text_buffer_get_insert (buf));
+			wg = lookup_widget (window_tutor_, "scrolledwindow_tutor_main");
+			scroll = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (wg));
 			gtk_adjustment_set_value (scroll,
-						  gtk_adjustment_get_value
-						  (scroll) + 3 * 23 * (n >
-								       0 ? 1 :
-								       -1));
+						  gtk_adjustment_get_value (scroll) + 3 * 23 * (n > 0 ? 1 : -1));
 		}
 	}
 	return (i);
@@ -137,8 +117,7 @@ cursor_paint_char (gchar * color_tag_name)
 
 	wg = lookup_widget (window_tutor_, "text_tutor");
 	buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (wg));
-	gtk_text_buffer_get_iter_at_mark (buf, &start,
-					  gtk_text_buffer_get_insert (buf));
+	gtk_text_buffer_get_iter_at_mark (buf, &start, gtk_text_buffer_get_insert (buf));
 	end = start;
 	gtk_text_iter_forward_char (&end);
 
@@ -161,10 +140,8 @@ cursor_get_char ()
 
 	wg = lookup_widget (window_tutor_, "text_tutor");
 	buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (wg));
-	gtk_text_buffer_get_iter_at_mark (buf, &start,
-					  gtk_text_buffer_get_insert (buf));
-	gtk_text_buffer_get_iter_at_mark (buf, &end,
-					  gtk_text_buffer_get_insert (buf));
+	gtk_text_buffer_get_iter_at_mark (buf, &start, gtk_text_buffer_get_insert (buf));
+	gtk_text_buffer_get_iter_at_mark (buf, &end, gtk_text_buffer_get_insert (buf));
 	gtk_text_iter_forward_char (&end);
 	tmp_str = gtk_text_buffer_get_text (buf, &start, &end, FALSE);
 	chr = g_utf8_get_char (tmp_str);
@@ -242,10 +219,8 @@ cursor_switch_on ()
 	wg_text = GTK_TEXT_VIEW (lookup_widget (window_tutor_, "text_tutor"));
 	buf = gtk_text_view_get_buffer (wg_text);
 
-	gtk_text_buffer_get_iter_at_mark (buf, &start,
-					  gtk_text_buffer_get_insert (buf));
-	gtk_text_buffer_get_iter_at_mark (buf, &end,
-					  gtk_text_buffer_get_insert (buf));
+	gtk_text_buffer_get_iter_at_mark (buf, &start, gtk_text_buffer_get_insert (buf));
+	gtk_text_buffer_get_iter_at_mark (buf, &end, gtk_text_buffer_get_insert (buf));
 	gtk_text_iter_forward_char (&end);
 	gtk_text_buffer_apply_tag_by_name (buf, "cursor_blink", &start, &end);
 }
@@ -264,11 +239,8 @@ cursor_switch_off ()
 	wg_text = GTK_TEXT_VIEW (lookup_widget (window_tutor_, "text_tutor"));
 	buf = gtk_text_view_get_buffer (wg_text);
 
-	gtk_text_buffer_get_iter_at_mark (buf, &start,
-					  gtk_text_buffer_get_insert (buf));
-	gtk_text_buffer_get_iter_at_mark (buf, &end,
-					  gtk_text_buffer_get_insert (buf));
+	gtk_text_buffer_get_iter_at_mark (buf, &start, gtk_text_buffer_get_insert (buf));
+	gtk_text_buffer_get_iter_at_mark (buf, &end, gtk_text_buffer_get_insert (buf));
 	gtk_text_iter_forward_char (&end);
-	gtk_text_buffer_remove_tag_by_name (buf, "cursor_blink", &start,
-					    &end);
+	gtk_text_buffer_remove_tag_by_name (buf, "cursor_blink", &start, &end);
 }
