@@ -1,6 +1,6 @@
 /**************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                               */
-/*  Copyright (C) 2005 - 2007  Felipe Castro                              */
+/*  Copyright (C) 2005 - 2008  Felipe Castro                              */
 /*                                                                        */
 /*  This program is free software, licensed under the terms of the GNU    */
 /*  General Public License as published by the Free Software Foundation,  */
@@ -83,8 +83,7 @@ get_par (gint index)
 	size = par_2 - par_1;
 	if (size < 1)
 	{
-		g_message ("internal error while picking the paragraph %i.",
-			   index);
+		g_message ("internal error while picking the paragraph %i.", index);
 		par_i = g_strdup_printf ("#%i\n", index);
 	}
 	else
@@ -111,20 +110,14 @@ fluid_init ()
 		main_preferences_set_int ("tutor", "fluid_paragraphs", 3);
 
 	wg = lookup_widget (window_tutor_, "spinbutton_lesson");
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (wg),
-				   main_preferences_get_int ("tutor",
-							     "fluid_paragraphs"));
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (wg), main_preferences_get_int ("tutor", "fluid_paragraphs"));
 
 	if (par.len == 0)
 	{
 		if (main_preferences_exist ("tutor", "paragraph_list"))
 		{
-			tmp_str =
-				main_preferences_get_string ("tutor",
-							     "paragraph_list");
-			tmp_name =
-				g_strconcat (main_get_user_dir (), tmp_str,
-					     ".paragraphs", NULL);
+			tmp_str = main_preferences_get_string ("tutor", "paragraph_list");
+			tmp_name = g_strconcat (main_get_user_dir (), tmp_str, ".paragraphs", NULL);
 			if ((fh = (FILE *) g_fopen (tmp_name, "r")))
 			{
 				fluid_init_paragraph_list (tmp_str);
@@ -153,11 +146,8 @@ fluid_init_paragraph_list (gchar * list_name)
 
 	if (list_name && strcmp (list_name, _("--> Default")) != 0)
 	{
-		main_preferences_set_string ("tutor", "paragraph_list",
-					     list_name);
-		tmp_name =
-			g_strconcat (main_get_user_dir (), list_name,
-				     ".paragraphs", NULL);
+		main_preferences_set_string ("tutor", "paragraph_list", list_name);
+		tmp_name = g_strconcat (main_get_user_dir (), list_name, ".paragraphs", NULL);
 		g_message ("loading text file: %s.paragraphs", list_name);
 		strncpy (par.name, list_name, 20);
 		par.name[20] = '\0';
@@ -165,11 +155,8 @@ fluid_init_paragraph_list (gchar * list_name)
 	else
 	{
 		main_preferences_remove ("tutor", "paragraph_list");
-		tmp_code =
-			main_preferences_get_string ("interface", "language");
-		tmp_name =
-			g_strconcat (main_get_data_path (), tmp_code,
-				     ".paragraphs", NULL);
+		tmp_code = main_preferences_get_string ("interface", "language");
+		tmp_name = g_strconcat (main_get_data_path (), tmp_code, ".paragraphs", NULL);
 		g_message ("loading text file: %s.paragraphs", tmp_code);
 		strcpy (par.name, "Default");
 		g_free (tmp_code);
@@ -209,14 +196,12 @@ fluid_init_paragraph_list (gchar * list_name)
 	{
 		g_message ("could not open the file: %s", tmp_name);
 		g_free (tmp_name);
-		tmp_code =
-			main_preferences_get_string ("interface", "language");
+		tmp_code = main_preferences_get_string ("interface", "language");
 		if (strcmp (tmp_code, "C") == 0)
 			g_error ("so, we must quit!");
 		main_preferences_set_string ("interface", "language", "C");
 		fluid_init_paragraph_list (list_name);
-		main_preferences_set_string ("interface", "language",
-					     tmp_code);
+		main_preferences_set_string ("interface", "language", tmp_code);
 		g_free (tmp_code);
 		return;
 	}
@@ -232,8 +217,7 @@ fluid_draw_random_paragraphs ()
 	gint i, j;
 	gint par_num;
 	gint rand_i[10];
-	static gchar *text[10] =
-		{ NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
+	static gchar *text[10] = { NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
 		NULL
 	};
 
@@ -279,8 +263,7 @@ fluid_copy_text_file (gchar * file_name)
 	if (!file_name)
 	{
 		gdk_beep ();
-		g_warning
-			("fluid_copy_text_file(): null file name as argument.");
+		g_warning ("fluid_copy_text_file(): null file name as argument.");
 		return;
 	}
 
@@ -292,9 +275,7 @@ fluid_copy_text_file (gchar * file_name)
 	}
 
 	pars_name = g_strdup (strrchr (file_name, DIRSEP) + 1);
-	pars_path =
-		g_strconcat (main_get_user_dir (), pars_name, ".paragraphs",
-			     NULL);
+	pars_path = g_strconcat (main_get_user_dir (), pars_name, ".paragraphs", NULL);
 
 	assert_user_dir ();
 	if (!(fh_destiny = (FILE *) g_fopen (pars_path, "w")))
@@ -313,24 +294,24 @@ fluid_copy_text_file (gchar * file_name)
 	 */
 	empty_file = TRUE;
 	nlin = 0;
-	g_print ("Processing file:\n %s\nParagraphs:\n0", file_name);
+	//g_print ("Processing file:\n %s\nParagraphs:\n0", file_name);
 	while (fgets (tmp_str, MAX_PAR_LEN, fh_source) != NULL)
 	{
 		if (nlin++ > MAX_PARAGRAPHS)
 		{
-			g_print (" - truncated!");
+			//g_print (" - truncated!");
 			break;
 		}
 		g_print (" - %u", nlin);
 
 		if (g_utf8_validate (tmp_str, -1, NULL) == FALSE)
 		{
-			g_print (": NOT UTF8!");
+			//g_print (": NOT UTF8!");
 			continue;
 		}
 		if (strcmp (tmp_str, "\n") == 0)
 		{
-			g_print (": BLANK!");
+			//g_print (": BLANK!");
 			continue;
 		}
 
@@ -349,7 +330,7 @@ fluid_copy_text_file (gchar * file_name)
 	fclose (fh_source);
 	fclose (fh_destiny);
 
-	g_print (" - end.\n");
+	//g_print (" - end.\n");
 
 	fluid_init_paragraph_list (pars_name);
 	tutor_set_query (QUERY_INTRO);
@@ -365,7 +346,7 @@ fluid_copy_text_file (gchar * file_name)
 void
 fluid_comment (gdouble accuracy, gdouble velocity, gdouble fluidness)
 {
-	gchar str[1000];
+	gchar *tmp_str;
 	GtkWidget *wg;
 	GtkTextBuffer *buf;
 
@@ -373,35 +354,28 @@ fluid_comment (gdouble accuracy, gdouble velocity, gdouble fluidness)
 	 * Comments
 	 */
 	if (accuracy < 98)
-		sprintf (str,
-			 _(" Your accuracy rate is too low.\n"
-			   " I want it greater than 98 %%.\n"));
+		tmp_str = g_strdup (_(" Your accuracy rate is too low.\n" " I want it greater than 98 %%.\n"));
 	else if (velocity < 50)
-		sprintf (str, _(" You type accurately but not fast.\n"
-				" Can you reach 50 WPM?\n"));
+		tmp_str = g_strdup (_(" You type accurately but not fast.\n" " Can you reach 50 WPM?\n"));
 	else if (fluidness < 70)
-		sprintf (str,
-			 _(" Your rhythm is not so constant. Calm down.\n"
-			   " For now, try to make the fluidness greater than 70 %%.\n"));
+		tmp_str = g_strdup (_(" Your rhythm is not so constant. Calm down.\n"
+				      " For now, try to make the fluidness greater than 70 %%.\n"));
 	else if (fluidness < 90)
-		sprintf (str,
-			 _
-			 (" You are almost getting there. Type more fluently.\n"
-			  " I want a fluidness greater than 90 %%.\n"));
+		tmp_str = g_strdup (_(" You are almost getting there. Type more fluently.\n"
+				      " I want a fluidness greater than 90 %%.\n"));
 	else if (velocity < 80)
-		sprintf (str,
-			 _(" Congratulations!\n"
-			   " It seems to me that you are a professional.\n"
-			   " You don't need this program (me) anymore.\n"
-			   " Hope you have enjoyed. Thanks and be happy!\n"));
+		tmp_str = g_strdup (_(" Congratulations!\n"
+				      " It seems to me that you are a professional.\n"
+				      " You don't need this program (me) anymore.\n"
+				      " Hope you have enjoyed. Thanks and be happy!\n"));
 	else
-		sprintf (str,
-			 _(" How can you type so fast?\n"
-			   " You have exceeded all my expectations.\n"
-			   " Are you a machine? Could you teach me?\n"
-			   " I can not help you anymore. Go to an expert!\n"));
+		tmp_str = g_strdup (_(" How can you type so fast?\n"
+				      " You have exceeded all my expectations.\n"
+				      " Are you a machine? Could you teach me?\n"
+				      " I can not help you anymore. Go to an expert!\n"));
 
 	wg = lookup_widget (window_tutor_, "text_tutor");
 	buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (wg));
-	gtk_text_buffer_insert_at_cursor (buf, str, strlen (str));
+	gtk_text_buffer_insert_at_cursor (buf, tmp_str, strlen (tmp_str));
+	g_free (tmp_str);
 }
