@@ -1,3 +1,12 @@
+/**************************************************************************/
+/*  Klavaro - a flexible touch typing tutor                               */
+/*  Copyright (C) 2005 - 2008  Felipe Castro                              */
+/*                                                                        */
+/*  This program is free software, licensed under the terms of the GNU    */
+/*  General Public License as published by the Free Software Foundation,  */
+/*  which is also included in this package, in a file named "COPYING".    */
+/**************************************************************************/
+
 /* GtkDatabox - An extension to the gtk+ library
  * Copyright (C) 1998 - 2005  Dr. Roland Bock
  *
@@ -157,27 +166,15 @@ extern "C"
 
 		/* Funktion pointers for signals, needed (mostly) for gtk-- wrapper */
 		/* For use of the signals, see "examples/signals.c" */
-		void (*gtk_databox_motion_notify) (GtkDatabox * box,
-						   GtkDataboxCoord *
-						   position);
+		void (*gtk_databox_motion_notify) (GtkDatabox * box, GtkDataboxCoord * position);
 		void (*gtk_databox_zoomed) (GtkDatabox * box,
-					    GtkDataboxValue * top_left,
-					    GtkDataboxValue * bottom_right);
-		void (*gtk_databox_marked) (GtkDatabox * box,
-					    GtkDataboxCoord * marked);
-		void (*gtk_databox_selection_started) (GtkDatabox * box,
-						       GtkDataboxCoord *
-						       marked);
+					    GtkDataboxValue * top_left, GtkDataboxValue * bottom_right);
+		void (*gtk_databox_marked) (GtkDatabox * box, GtkDataboxCoord * marked);
+		void (*gtk_databox_selection_started) (GtkDatabox * box, GtkDataboxCoord * marked);
 		void (*gtk_databox_selection_changed) (GtkDatabox * box,
-						       GtkDataboxCoord *
-						       marked,
-						       GtkDataboxCoord *
-						       select);
+						       GtkDataboxCoord * marked, GtkDataboxCoord * select);
 		void (*gtk_databox_selection_stopped) (GtkDatabox * box,
-						       GtkDataboxCoord *
-						       marked,
-						       GtkDataboxCoord *
-						       select);
+						       GtkDataboxCoord * marked, GtkDataboxCoord * select);
 		void (*gtk_databox_selection_cancelled) (GtkDatabox * box);
 
 	};
@@ -219,9 +216,7 @@ extern "C"
    The return value is the internal index of the data.
    */
 	gint gtk_databox_data_add_x_y (GtkDatabox * box, guint length,
-				       gfloat * X, gfloat * Y, GdkColor color,
-				       GtkDataboxDataType type,
-				       guint dot_size);
+				       gfloat * X, gfloat * Y, GdkColor color, GtkDataboxDataType type, guint dot_size);
 
 /* This function is used for adding another set of data to your 
    GtkDatabox that has the same Y values as one of the added 
@@ -230,8 +225,7 @@ extern "C"
    See gtk_databox_data_add_x_y for additional information. */
 	gint gtk_databox_data_add_x (GtkDatabox * box, guint length,
 				     gfloat * X, gint shared_Y_index,
-				     GdkColor color, GtkDataboxDataType type,
-				     guint dot_size);
+				     GdkColor color, GtkDataboxDataType type, guint dot_size);
 
 /* This function is used for adding another set of data to your 
    GtkDatabox that has the same X values as one of the added 
@@ -240,8 +234,7 @@ extern "C"
    See gtk_databox_data_add_x_y for additional information. */
 	gint gtk_databox_data_add_y (GtkDatabox * box, guint length,
 				     gfloat * Y, gint shared_X_index,
-				     GdkColor color, GtkDataboxDataType type,
-				     guint dot_size);
+				     GdkColor color, GtkDataboxDataType type, guint dot_size);
 
 /* The next two funtions are used to remove data sets from the 
    GtkDatabox. They remove the set with the given index or all sets.
@@ -276,32 +269,22 @@ extern "C"
    if your data contains a few "wrong" values that are far away from 
    the interesting parts. */
 	void gtk_databox_rescale (GtkDatabox * box);
-	void gtk_databox_rescale_with_values (GtkDatabox * box,
-					      GtkDataboxValue min,
-					      GtkDataboxValue max);
+	void gtk_databox_rescale_with_values (GtkDatabox * box, GtkDataboxValue min, GtkDataboxValue max);
 
 /* Automatic rescaling arranges the values so that (minX, minY) are located 
    in the left bottom of the widget and the (maxX, maxY) is found on the 
    right top. 
    By calling gtk_databox_rescale_inverted, you can opt for an inverted 
    arrangement in X and/or Y direction. */
-	void gtk_databox_rescale_inverted (GtkDatabox * box,
-					   gboolean invertX,
-					   gboolean invertY);
+	void gtk_databox_rescale_inverted (GtkDatabox * box, gboolean invertX, gboolean invertY);
 
 /* Use the following functions to get or set the color and type 
    of your displayed data. The index is the return value of 
    gtk_databox_data_add_x_y or similar function. */
-	gint gtk_databox_data_set_color (GtkDatabox * box, gint index,
-					 GdkColor color);
-	gint gtk_databox_data_get_color (GtkDatabox * box, gint index,
-					 GdkColor * color);
-	gint gtk_databox_data_set_type (GtkDatabox * box, gint index,
-					GtkDataboxDataType type,
-					guint dot_size);
-	gint gtk_databox_data_get_type (GtkDatabox * box, gint index,
-					GtkDataboxDataType * type,
-					guint * dot_size);
+	gint gtk_databox_data_set_color (GtkDatabox * box, gint index, GdkColor color);
+	gint gtk_databox_data_get_color (GtkDatabox * box, gint index, GdkColor * color);
+	gint gtk_databox_data_set_type (GtkDatabox * box, gint index, GtkDataboxDataType type, guint dot_size);
+	gint gtk_databox_data_get_type (GtkDatabox * box, gint index, GtkDataboxDataType * type, guint * dot_size);
 
 /* The next two functions do nothing useful unless the data type is GRID.
    Adding data and using it as grid or coordinate cross afterwards looks 
@@ -309,38 +292,29 @@ extern "C"
    is one of my own benefits) or being able to make  sure that you 
    have your grid below, between or on top of the rest of the data (that is 
    supposed to be your benefit...) */
-	gint gtk_databox_data_set_grid_config (GtkDatabox * box, gint index,
-					       guint hlines, guint vlines);
-	gint gtk_databox_data_get_grid_config (GtkDatabox * box, gint index,
-					       guint * hlines,
-					       guint * vlines);
+	gint gtk_databox_data_set_grid_config (GtkDatabox * box, gint index, guint hlines, guint vlines);
+	gint gtk_databox_data_get_grid_config (GtkDatabox * box, gint index, guint * hlines, guint * vlines);
 
 /* The following function calculates the "data coordinates" for
    a given pair of pixel coordinates. The results of this 
    calculation depend on your current zoom/scroll status, and on 
    the last rescale action, see gtk_databox_rescale and 
    gtk_databox_rescale_with_values. */
-	void gtk_databox_data_get_value (GtkDatabox * box,
-					 GtkDataboxCoord coord,
-					 GtkDataboxValue * value);
+	void gtk_databox_data_get_value (GtkDatabox * box, GtkDataboxCoord coord, GtkDataboxValue * value);
 
 /* Get the minimum X/Y and the maximum X/Y "data coordinates". These
    are the coordinates of the bottom-left and top-right corners when 
    you zoom out completely (shift + button-3). 
    The result depends on the last call of gtk_databox_rescale or
    gtk_databox_rescale_with_values */
-	void gtk_databox_data_get_extrema (GtkDatabox * box,
-					   GtkDataboxValue * min,
-					   GtkDataboxValue * max);
+	void gtk_databox_data_get_extrema (GtkDatabox * box, GtkDataboxValue * min, GtkDataboxValue * max);
 /* Get the "data coordinates" (not the pixel coordinates) of the 
    bottom-left and top-right corners of the visible data currently 
    shown in the GtkDatabox. When zoomed out completely 
    the result will be the same as for gtk_databox_data_get_extrema 
    The result depends on the last call of gtk_databox_rescale or
    gtk_databox_rescale_with_values */
-	void gtk_databox_data_get_visible_extrema (GtkDatabox * box,
-						   GtkDataboxValue * min,
-						   GtkDataboxValue * max);
+	void gtk_databox_data_get_visible_extrema (GtkDatabox * box, GtkDataboxValue * min, GtkDataboxValue * max);
 
 
 /* Even you are happy with the default behaviour of the GtkDatabox
@@ -349,29 +323,24 @@ extern "C"
 
 /* This color allows you to set the background color of the GtkDatabox. */
 
-	void gtk_databox_set_background_color (GtkDatabox * box,
-					       GdkColor color);
+	void gtk_databox_set_background_color (GtkDatabox * box, GdkColor color);
 
 /* By default, the GtkDatabox will come with a pair of scrollbars and
    rulers. Use the following functions to get rid of them or 
    get them back again */
 
-	void gtk_databox_set_rulers_enable (GtkDatabox * box,
-					    gboolean enable);
+	void gtk_databox_set_rulers_enable (GtkDatabox * box, gboolean enable);
 	gboolean gtk_databox_get_rulers_enable (GtkDatabox * box);
-	void gtk_databox_set_scrollbars_enable (GtkDatabox * box,
-						gboolean enable);
+	void gtk_databox_set_scrollbars_enable (GtkDatabox * box, gboolean enable);
 	gboolean gtk_databox_get_scrollbars_enable (GtkDatabox * box);
 
 /* Selection is possible as default, but you may disable that feature */
-	void gtk_databox_set_selection_enable (GtkDatabox * box,
-					       gboolean enable);
+	void gtk_databox_set_selection_enable (GtkDatabox * box, gboolean enable);
 	gboolean gtk_databox_get_selection_enable (GtkDatabox * box);
 
 /* Decide whether the selection box is filled or not, the default
    is not filled */
-	void gtk_databox_set_selection_fill_enable (GtkDatabox * box,
-						    gboolean enable);
+	void gtk_databox_set_selection_fill_enable (GtkDatabox * box, gboolean enable);
 	gboolean gtk_databox_get_selection_fill_enable (GtkDatabox * box);
 
 /* Zooming into the data and back is enabled as default, but you 
