@@ -1,3 +1,12 @@
+/**************************************************************************/
+/*  Klavaro - a flexible touch typing tutor                               */
+/*  Copyright (C) 2005 - 2008  Felipe Castro                              */
+/*                                                                        */
+/*  This program is free software, licensed under the terms of the GNU    */
+/*  General Public License as published by the Free Software Foundation,  */
+/*  which is also included in this package, in a file named "COPYING".    */
+/**************************************************************************/
+
 /* GtkDatabox - An extension to the gtk+ library
  * Copyright (C) 1998 - 2005  Dr. Roland Bock
  *
@@ -27,14 +36,10 @@ void
 gtk_databox_marshal_VOID__POINTER_POINTER (GClosure * closure,
 					   GValue * return_value,
 					   guint n_param_values,
-					   const GValue * param_values,
-					   gpointer invocation_hint,
-					   gpointer marshal_data)
+					   const GValue * param_values, gpointer invocation_hint, gpointer marshal_data)
 {
 	typedef void (*GMarshalFunc_VOID__POINTER_POINTER) (gpointer data1,
-							    gpointer arg_1,
-							    gpointer arg_2,
-							    gpointer data2);
+							    gpointer arg_1, gpointer arg_2, gpointer data2);
 	register GMarshalFunc_VOID__POINTER_POINTER callback;
 	register GCClosure *cc = (GCClosure *) closure;
 	register gpointer data1, data2;
@@ -51,10 +56,7 @@ gtk_databox_marshal_VOID__POINTER_POINTER (GClosure * closure,
 		data1 = g_value_peek_pointer (param_values + 0);
 		data2 = closure->data;
 	}
-	callback =
-		(GMarshalFunc_VOID__POINTER_POINTER) (marshal_data ?
-						      marshal_data : cc->
-						      callback);
+	callback = (GMarshalFunc_VOID__POINTER_POINTER) (marshal_data ? marshal_data : cc->callback);
 
 	callback (data1,
 		  g_marshal_value_peek_pointer (param_values + 1),
