@@ -1,6 +1,6 @@
 /**************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                               */
-/*  Copyright (C) 2005 - 2007  Felipe Castro                              */
+/*  Copyright (C) 2005 - 2008  Felipe Castro                              */
 /*                                                                        */
 /*  This program is free software, licensed under the terms of the GNU    */
 /*  General Public License as published by the Free Software Foundation,  */
@@ -114,8 +114,7 @@ keyb_get_layout ()
 	/*
 	 * Search at home
 	 */
-	tmp_name =
-		g_strconcat (main_get_user_dir (), keyb.name, ".kbd", NULL);
+	tmp_name = g_strconcat (main_get_user_dir (), keyb.name, ".kbd", NULL);
 	fh = (FILE *) g_fopen (tmp_name, "r");
 	if (fh == NULL)
 	{
@@ -123,9 +122,7 @@ keyb_get_layout ()
 		 * Search at data
 		 */
 		g_free (tmp_name);
-		tmp_name =
-			g_strconcat (main_get_data_path (), keyb.name, ".kbd",
-				     NULL);
+		tmp_name = g_strconcat (main_get_data_path (), keyb.name, ".kbd", NULL);
 		fh = (FILE *) g_fopen (tmp_name, "r");
 	}
 	g_free (tmp_name);
@@ -141,10 +138,8 @@ keyb_get_layout ()
 			if (n_itens > KEY_LINE_LEN)
 				g_error ("invalid keyboard layout: %s\n"
 					 "invalid line: %i\n"
-					 "invalid number of chars: %li",
-					 keyb.name, i + 1, n_itens);
-			memcpy (keyb.lochars[i], uchs,
-				(n_itens - 1) * sizeof (gunichar));
+					 "invalid number of chars: %li", keyb.name, i + 1, n_itens);
+			memcpy (keyb.lochars[i], uchs, (n_itens - 1) * sizeof (gunichar));
 			g_free (uchs);
 			for (; n_itens < KEY_LINE_LEN; n_itens++)
 				keyb.lochars[i][n_itens] = L' ';
@@ -157,10 +152,8 @@ keyb_get_layout ()
 			if (n_itens > KEY_LINE_LEN)
 				g_error ("invalid keyboard layout: %s\n"
 					 "invalid line: %i\n"
-					 "invalid number of chars: %li",
-					 keyb.name, i + 5, n_itens);
-			memcpy (keyb.upchars[i], uchs,
-				(n_itens - 1) * sizeof (gunichar));
+					 "invalid number of chars: %li", keyb.name, i + 5, n_itens);
+			memcpy (keyb.upchars[i], uchs, (n_itens - 1) * sizeof (gunichar));
 			g_free (uchs);
 			for (; n_itens < KEY_LINE_LEN; n_itens++)
 				keyb.upchars[i][n_itens] = L' ';
@@ -181,16 +174,13 @@ keyb_get_layout ()
 		if (strcmp (keyb.name, "") == 0)
 		{
 			g_free (keyb.name);
-			keyb.name =
-				gtk_editable_get_chars (GTK_EDITABLE (wg), 0,
-							-1);
+			keyb.name = gtk_editable_get_chars (GTK_EDITABLE (wg), 0, -1);
 			keyb_get_layout ();
 			return;
 		}
 
 		g_message ("couldn't find the keyboard layout: \"%s\"\n"
-			   " Opening the default one: \"%s\"", keyb.name,
-			   DEFAULT_KEYBOARD);
+			   " Opening the default one: \"%s\"", keyb.name, DEFAULT_KEYBOARD);
 		gtk_entry_set_text (GTK_ENTRY (wg), DEFAULT_KEYBOARD);
 		g_free (keyb.name);
 		keyb.name = g_strconcat (DEFAULT_KEYBOARD, NULL);
@@ -255,8 +245,7 @@ keyb_get_consonants (gunichar * consonants)
 				consonants[k++] = chr;
 
 			chr = g_unichar_tolower (keyb.upchars[i][j]);
-			if (g_unichar_isalpha (chr) && (!keyb_is_vowel (chr))
-			    && (chr != keyb.lochars[i][j]))
+			if (g_unichar_isalpha (chr) && (!keyb_is_vowel (chr)) && (chr != keyb.lochars[i][j]))
 				consonants[k++] = chr;
 		}
 	return (k);
@@ -297,24 +286,19 @@ keyb_save_new_layout ()
 	FILE *fh;
 
 	assert_user_dir ();
-	tmp_name =
-		g_strconcat (main_get_user_dir (), keyb.name, ".kbd", NULL);
+	tmp_name = g_strconcat (main_get_user_dir (), keyb.name, ".kbd", NULL);
 	fh = (FILE *) g_fopen (tmp_name, "w");
 	g_free (tmp_name);
 
 	for (i = 0; i < 4; i++)
 	{
-		tmp_name =
-			g_ucs4_to_utf8 (keyb.lochars[i], KEY_LINE_LEN - 1,
-					NULL, NULL, NULL);
+		tmp_name = g_ucs4_to_utf8 (keyb.lochars[i], KEY_LINE_LEN - 1, NULL, NULL, NULL);
 		fprintf (fh, "%s\n", tmp_name);
 		g_free (tmp_name);
 	}
 	for (i = 0; i < 4; i++)
 	{
-		tmp_name =
-			g_ucs4_to_utf8 (keyb.upchars[i], KEY_LINE_LEN - 1,
-					NULL, NULL, NULL);
+		tmp_name = g_ucs4_to_utf8 (keyb.upchars[i], KEY_LINE_LEN - 1, NULL, NULL, NULL);
 		fprintf (fh, "%s\n", tmp_name);
 		g_free (tmp_name);
 	}
@@ -322,13 +306,10 @@ keyb_save_new_layout ()
 
 	gtk_widget_hide (lookup_widget (window_keyboard_, "label_modified"));
 	if (strcmp (keyb.name, ".tmp") == 0)
-		gtk_widget_show (lookup_widget
-				 (window_keyboard_, "label_saved_tmp"));
+		gtk_widget_show (lookup_widget (window_keyboard_, "label_saved_tmp"));
 	else
-		gtk_widget_hide (lookup_widget
-				 (window_keyboard_, "label_saved_tmp"));
-	gtk_widget_set_sensitive (lookup_widget
-				  (window_keyboard_, "label_kb_load"), TRUE);
+		gtk_widget_hide (lookup_widget (window_keyboard_, "label_saved_tmp"));
+	gtk_widget_set_sensitive (lookup_widget (window_keyboard_, "label_kb_load"), TRUE);
 	keyb.modified_status = FALSE;
 }
 
@@ -382,14 +363,10 @@ keyb_update_virtual_layout ()
 	tog_state = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (wg));
 	for (i = 0; i < 4; i++)
 	{
-		for (j = 0;
-		     j < KEY_LINE_LEN - (i == 0 ? 1 : (i == 1 ? 2 : 3)); j++)
+		for (j = 0; j < KEY_LINE_LEN - (i == 0 ? 1 : (i == 1 ? 2 : 3)); j++)
 		{
-			uch = tog_state ? keyb.upchars[i][j] : keyb.
-				lochars[i][j];
-			if (g_unichar_isalpha (uch)
-			    && g_unichar_tolower (keyb.upchars[i][j]) ==
-			    keyb.lochars[i][j])
+			uch = tog_state ? keyb.upchars[i][j] : keyb.lochars[i][j];
+			if (g_unichar_isalpha (uch) && g_unichar_tolower (keyb.upchars[i][j]) == keyb.lochars[i][j])
 				uch = g_unichar_toupper (uch);
 			snprintf (lab_name + (i + 3), 3, "%i", j + 1);
 			if ((wg = lookup_widget (window_keyboard_, lab_name)))
@@ -425,8 +402,7 @@ keyb_fill_layout_list (gint entry_type)
 		 */
 		dir = g_dir_open (main_get_data_path (), 0, NULL);
 		if (dir == NULL)
-			g_error ("could not find the data directory:/n %s/n",
-				 main_get_data_path ());
+			g_error ("could not find the data directory:/n %s/n", main_get_data_path ());
 	}
 	else if (entry_type == 2 || entry_type == 3)
 	{
@@ -449,8 +425,7 @@ keyb_fill_layout_list (gint entry_type)
 
 	kb_name_exists = FALSE;
 	i = 0;
-	while (i < MAX_KEYBOARDS
-	       && ((dentry = g_strdup (g_dir_read_name (dir))) != NULL))
+	while (i < MAX_KEYBOARDS && ((dentry = g_strdup (g_dir_read_name (dir))) != NULL))
 	{
 		name_len = strlen (dentry);
 		if (name_len > 20 || name_len < 5)
@@ -477,8 +452,7 @@ keyb_fill_layout_list (gint entry_type)
 
 		if (strcmp (tmp_name[i], keyb.name) != 0)
 		{
-			files = g_list_insert_sorted (files, tmp_name[i],
-						      comp_str);
+			files = g_list_insert_sorted (files, tmp_name[i], comp_str);
 			i++;
 		}
 		else
@@ -589,8 +563,7 @@ keyb_change_key (gunichar real_key)
 	{
 		keyb.upchars[key_lin][key_col] = str_char;
 		if (str_char >= L'A' && str_char <= L'Z')
-			keyb.lochars[key_lin][key_col] =
-				g_unichar_tolower (str_char);
+			keyb.lochars[key_lin][key_col] = g_unichar_tolower (str_char);
 	}
 	else
 	{
@@ -602,13 +575,9 @@ keyb_change_key (gunichar real_key)
 	if (keyb.modified_status == FALSE)
 	{
 		keyb.modified_status = TRUE;
-		gtk_widget_hide (lookup_widget
-				 (window_keyboard_, "label_saved_tmp"));
-		gtk_widget_show (lookup_widget
-				 (window_keyboard_, "label_modified"));
-		gtk_widget_set_sensitive (lookup_widget
-					  (window_keyboard_, "label_kb_load"),
-					  FALSE);
+		gtk_widget_hide (lookup_widget (window_keyboard_, "label_saved_tmp"));
+		gtk_widget_show (lookup_widget (window_keyboard_, "label_modified"));
+		gtk_widget_set_sensitive (lookup_widget (window_keyboard_, "label_kb_load"), FALSE);
 		wg = lookup_widget (window_keyboard_, "notebook_kb");
 		gtk_notebook_set_page (GTK_NOTEBOOK (wg), 1);
 	}
@@ -666,9 +635,7 @@ hints_init ()
 		return;
 
 	hints_is_initialized = TRUE;
-	tmp_name =
-		g_strconcat (main_get_data_path (), "fingers_position.txt",
-			     NULL);
+	tmp_name = g_strconcat (main_get_data_path (), "fingers_position.txt", NULL);
 	fh = (FILE *) g_fopen (tmp_name, "r");
 	if (fh)
 	{
@@ -837,6 +804,5 @@ hints_update_from_char (gunichar character)
 
 	wg = lookup_widget (window_hints_, "pixmap_hints");
 	hints_get_from_char (file_name, character);
-	gtk_image_set_from_file (GTK_IMAGE (wg),
-				 find_pixmap_file (file_name));
+	gtk_image_set_from_file (GTK_IMAGE (wg), find_pixmap_file (file_name));
 }
