@@ -1,6 +1,6 @@
 /**************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                               */
-/*  Copyright (C) 2005 - 2007  Felipe Castro                              */
+/*  Copyright (C) 2005 - 2008  Felipe Castro                              */
 /*                                                                        */
 /*  This program is free software, licensed under the terms of the GNU    */
 /*  General Public License as published by the Free Software Foundation,  */
@@ -125,8 +125,7 @@ main (int argc, char *argv[])
 	gtk_disable_setlocale ();	/* The locale will be set according to user preference... */
 	gtk_init (&argc, &argv);
 
-	add_pixmap_directory (PACKAGE_DATA_DIR DIRSEP_S PACKAGE DIRSEP_S
-			      "pixmaps");
+	add_pixmap_directory (PACKAGE_DATA_DIR DIRSEP_S PACKAGE DIRSEP_S "pixmaps");
 	add_pixmap_directory (".." DIRSEP_S "pixmaps");
 
 	main_initialize_global_variables ();	/* Here the locale is set. */
@@ -153,9 +152,7 @@ change_oldprefs ()
 	tmp_old = g_strconcat (general.user_dir, "preferences.desktop", NULL);
 	if (g_file_test (tmp_old, G_FILE_TEST_EXISTS))
 	{
-		tmp_new =
-			g_strconcat (general.user_dir, "preferences.ini",
-				     NULL);
+		tmp_new = g_strconcat (general.user_dir, "preferences.ini", NULL);
 		g_rename (tmp_old, tmp_new);
 		g_free (tmp_new);
 	}
@@ -174,9 +171,7 @@ main_initialize_global_variables ()
 	/*
 	 * Set the home user dir 
 	 */
-	general.user_dir =
-		g_strconcat (g_get_home_dir (), DIRSEP_S ".klavaro" DIRSEP_S,
-			     NULL);
+	general.user_dir = g_strconcat (g_get_home_dir (), DIRSEP_S ".klavaro" DIRSEP_S, NULL);
 	/*
 	 * Get a valid data path.
 	 * First searches the path at the source directory.
@@ -188,16 +183,12 @@ main_initialize_global_variables ()
 	{
 		g_free (general.data_path);
 		g_free (tmp_name);
-		general.data_path =
-			g_strdup (PACKAGE_DATA_DIR DIRSEP_S PACKAGE DIRSEP_S);
-		tmp_name =
-			g_strconcat (general.data_path, "basic_lessons.txt",
-				     NULL);
+		general.data_path = g_strdup (PACKAGE_DATA_DIR DIRSEP_S PACKAGE DIRSEP_S);
+		tmp_name = g_strconcat (general.data_path, "basic_lessons.txt", NULL);
 		fh = (FILE *) g_fopen (tmp_name, "r");
 	}
 	if (fh == NULL)
-		g_error ("couldn't find a data file at the data path:\n %s",
-			 tmp_name);
+		g_error ("couldn't find a data file at the data path:\n %s", tmp_name);
 	fclose (fh);
 	g_free (tmp_name);
 
@@ -209,12 +200,9 @@ main_initialize_global_variables ()
 	preferences = g_key_file_new ();
 	tmp_name = g_strconcat (general.user_dir, "preferences.ini", NULL);
 	if (g_file_test (tmp_name, G_FILE_TEST_EXISTS))
-		g_key_file_load_from_file (preferences, tmp_name,
-					   G_KEY_FILE_NONE, NULL);
+		g_key_file_load_from_file (preferences, tmp_name, G_KEY_FILE_NONE, NULL);
 	else
-		g_key_file_load_from_file (preferences,
-					   "/etc/klavaro_preferences.ini",
-					   G_KEY_FILE_NONE, NULL);
+		g_key_file_load_from_file (preferences, "/etc/klavaro_preferences.ini", G_KEY_FILE_NONE, NULL);
 	g_free (tmp_name);
 
 	/*
@@ -246,14 +234,11 @@ main_window_init ()
 	if (!main_preferences_exist ("tutor", "keyboard"))
 	{
 		gtk_entry_set_text (GTK_ENTRY (wg), DEFAULT_KEYBOARD);
-		g_key_file_set_string (preferences, "tutor", "keyboard",
-				       DEFAULT_KEYBOARD);
+		g_key_file_set_string (preferences, "tutor", "keyboard", DEFAULT_KEYBOARD);
 	}
 	else
 	{
-		tmp_str =
-			g_key_file_get_string (preferences, "tutor",
-					       "keyboard", NULL);
+		tmp_str = g_key_file_get_string (preferences, "tutor", "keyboard", NULL);
 		gtk_entry_set_text (GTK_ENTRY (wg), tmp_str);
 		g_free (tmp_str);
 	}
@@ -283,9 +268,7 @@ main_window_pass_away ()
 	tmp_name = g_strconcat (general.user_dir, "preferences.ini", NULL);
 	fh = (FILE *) g_fopen (tmp_name, "w");
 	if (fh == NULL)
-		g_warning
-			("couldn't save your preferences at the user folder:\n %s",
-			 tmp_name);
+		g_warning ("couldn't save your preferences at the user folder:\n %s", tmp_name);
 	else
 	{
 		g_free (tmp_name);
@@ -318,12 +301,10 @@ assert_user_dir ()
 	dh = g_dir_open (main_get_user_dir (), 0, NULL);
 	if (dh == NULL)
 	{
-		g_message ("creating an empty user folder:\n %s",
-			   main_get_user_dir ());
+		g_message ("creating an empty user folder:\n %s", main_get_user_dir ());
 
 #ifdef G_OS_UNIX
-		g_mkdir (main_get_user_dir (),
-			 S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH);
+		g_mkdir (main_get_user_dir (), S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH);
 #endif
 
 #ifdef G_OS_WIN32
