@@ -1,6 +1,6 @@
 /**************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                               */
-/*  Copyright (C) 2005 - 2007  Felipe Castro                              */
+/*  Copyright (C) 2005 - 2008  Felipe Castro                              */
 /*                                                                        */
 /*  This program is free software, licensed under the terms of the GNU    */
 /*  General Public License as published by the Free Software Foundation,  */
@@ -11,6 +11,7 @@
  * Charts management
  */
 #include <stdio.h>
+#include <string.h>
 #include <locale.h>
 #include <glib.h>
 #include <glib/gstdio.h>
@@ -55,8 +56,7 @@ plot_initialize (GtkWidget * widget)
 	gtk_widget_set_name (databox, "databox_stat");
 	gtk_widget_ref (databox);
 	gtk_object_set_data_full (GTK_OBJECT (window_stat_), "databox_stat",
-				  databox,
-				  (GtkDestroyNotify) gtk_widget_unref);
+				  databox, (GtkDestroyNotify) gtk_widget_unref);
 	gtk_container_add (GTK_CONTAINER (widget), databox);
 	gtk_widget_show (databox);
 
@@ -65,10 +65,8 @@ plot_initialize (GtkWidget * widget)
 	 */
 	gdk_color_parse (TUTOR_YELLOW_GREEN, &color);
 	index = gtk_databox_data_add_x_y (GTK_DATABOX (databox), DATA_POINTS,
-					  plot.x_data, plot.y_data, color,
-					  GTK_DATABOX_GRID, 1);
-	gtk_databox_data_set_grid_config (GTK_DATABOX (databox), index, 9,
-					  10);
+					  plot.x_data, plot.y_data, color, GTK_DATABOX_GRID, 1);
+	gtk_databox_data_set_grid_config (GTK_DATABOX (databox), index, 9, 10);
 
 	/*
 	 * Background color
@@ -90,14 +88,14 @@ plot_draw_chart (gint field)
 	guint64 aux;
 	gchar *tmp_locale;
 	gchar *tmp_name;
-	gchar tmp_str[200];
+	gchar tmp_str[2000];
 	FILE *fh;
 	gfloat accur[DATA_POINTS];
 	gfloat velo[DATA_POINTS];
 	gfloat fluid[DATA_POINTS];
 	gchar data[DATA_POINTS][20];
 	gchar hour[DATA_POINTS][20];
-	gchar lesson[DATA_POINTS][20];
+	gchar lesson[DATA_POINTS][199];
 	GdkColor color;
 	GtkWidget *wg;
 	GtkDataboxValue max = { 0, 0 };
@@ -134,19 +132,16 @@ plot_draw_chart (gint field)
 	 * Auxiliar variable to track the current lesson
 	 */
 	aux = basic_get_lesson ();
+	aux -= basic_get_lesson_increased ()? 1 : 0;
 	if (aux == 0)
 		aux++;
 	sprintf (tmp_str, "%d", (gint) aux);
-	gtk_label_set_text (GTK_LABEL
-			    (lookup_widget
-			     (window_stat_, "label_stat_lesson_n")), tmp_str);
+	gtk_label_set_text (GTK_LABEL (lookup_widget (window_stat_, "label_stat_lesson_n")), tmp_str);
 
 	/*
 	 * Get the file name
 	 */
-	tmp_name =
-		g_strconcat (main_get_user_dir (), "stat_",
-			     tutor_get_type_name (), ".txt", NULL);
+	tmp_name = g_strconcat (main_get_user_dir (), "stat_", tutor_get_type_name (), ".txt", NULL);
 
 	/*
 	 * Open the data file
@@ -162,20 +157,20 @@ plot_draw_chart (gint field)
 	/*
 	 * Reads the first line (header)
 	 */
-	if (!fgets (tmp_str, 200, fh))
+	if (!fgets (tmp_str, 2000, fh))
 	{
 		g_message ("no data on the statistic file:\n%s", tmp_name);
 		g_free (tmp_name);
 		fclose (fh);
 		return;
 	}
-	g_free (tmp_name);
 
 	/*
 	 * Changing to "C" locale
 	 */
 	tmp_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
-	setlocale (LC_NUMERIC, "C");
+	if (tmp_locale != NULL)
+		setlocale (LC_NUMERIC, "C");
 
 	/*
 	 * Reads the first DATA_POINTS points
@@ -184,10 +179,15 @@ plot_draw_chart (gint field)
 		plot.y_data[i] = -1000;
 
 	i = 0;
-	while (fscanf
-	       (fh, "%f%f%f%s%s%s", &accur[i], &velo[i], &fluid[i], data[i],
-		hour[i], lesson[i]) == 6)
+	while (fscanf (fh, "%f%f%f%s%s", &accur[i], &velo[i], &fluid[i], data[i], hour[i]) == 5)
 	{
+		if (fgets (lesson[i], 199, fh) == NULL)
+			break;
+		if (strlen (lesson[i]) == 199)
+			g_warning
+				("file name of custom lesson too long in line %i of %s: the limit is 199 characters.",
+				 i, tmp_name);
+
 		if (accur[i] > 100)
 			accur[i] = 100;
 		if (accur[i] < 80)
@@ -201,8 +201,7 @@ plot_draw_chart (gint field)
 		if (fluid[i] < 0)
 			fluid[i] = 0;
 
-		if (tutor_get_type () == TT_BASIC &&
-		    g_ascii_strtoull (lesson[i], NULL, 10) != aux)
+		if (tutor_get_type () == TT_BASIC && g_ascii_strtoull (lesson[i], NULL, 10) != aux)
 			continue;
 		switch (field)
 		{
@@ -223,10 +222,15 @@ plot_draw_chart (gint field)
 	/*
 	 * Reads until the end, keeping the last DATA_POINTS points 
 	 */
-	while (fscanf
-	       (fh, "%f%f%f%s%s%s", &accur[i], &velo[i], &fluid[i], data[i],
-		hour[i], lesson[i]) == 6)
+	while (fscanf (fh, "%f%f%f%s%s", &accur[i], &velo[i], &fluid[i], data[i], hour[i]) == 5)
 	{
+		if (fgets (lesson[i], 199, fh) == NULL)
+			break;
+		if (strlen (lesson[i]) == 199)
+			g_warning
+				("file name of custom lesson too long in line %i of %s: the limit is 199 characters.",
+				 i, tmp_name);
+
 		if (accur[i] > 100)
 			accur[i] = 100;
 		if (accur[i] < 80)
@@ -240,8 +244,7 @@ plot_draw_chart (gint field)
 		if (fluid[i] < 0)
 			fluid[i] = 0;
 
-		if (tutor_get_type () == TT_BASIC &&
-		    g_ascii_strtoull (lesson[i], NULL, 10) != aux)
+		if (tutor_get_type () == TT_BASIC && g_ascii_strtoull (lesson[i], NULL, 10) != aux)
 			continue;
 		for (i = 0; i < DATA_POINTS - 1; i++)
 			plot.y_data[i] = plot.y_data[i + 1];
@@ -260,11 +263,13 @@ plot_draw_chart (gint field)
 		i++;
 	}
 	fclose (fh);
+	g_free (tmp_name);
 
 	/*
 	 * Coming back to the right locale
 	 */
-	setlocale (LC_NUMERIC, tmp_locale);
+	if (tmp_locale != NULL)
+		setlocale (LC_NUMERIC, tmp_locale);
 	g_free (tmp_locale);
 
 	if (i == 0)
@@ -279,18 +284,13 @@ plot_draw_chart (gint field)
 	wg = lookup_widget (window_stat_, "databox_stat");
 	gtk_databox_data_remove_all (GTK_DATABOX (wg));
 	gdk_color_parse (TUTOR_GREEN, &color);
-	gtk_databox_data_add_x_y (GTK_DATABOX (wg), i, plot.x_data,
-				  plot.y_data, color, GTK_DATABOX_POINTS, 3);
+	gtk_databox_data_add_x_y (GTK_DATABOX (wg), i, plot.x_data, plot.y_data, color, GTK_DATABOX_POINTS, 3);
 	gdk_color_parse (TUTOR_BLACK, &color);
-	gtk_databox_data_add_x_y (GTK_DATABOX (wg), i, plot.x_data,
-				  plot.y_data, color, GTK_DATABOX_POINTS, 5);
-	gtk_databox_data_add_x_y (GTK_DATABOX (wg), i, plot.x_data,
-				  plot.y_data, color, GTK_DATABOX_LINES, 1);
+	gtk_databox_data_add_x_y (GTK_DATABOX (wg), i, plot.x_data, plot.y_data, color, GTK_DATABOX_POINTS, 5);
+	gtk_databox_data_add_x_y (GTK_DATABOX (wg), i, plot.x_data, plot.y_data, color, GTK_DATABOX_LINES, 1);
 
 	gdk_color_parse (TUTOR_YELLOW_GREEN, &color);
-	index = gtk_databox_data_add_x_y (GTK_DATABOX (wg), i, plot.x_data,
-					  plot.y_data, color,
-					  GTK_DATABOX_GRID, 1);
+	index = gtk_databox_data_add_x_y (GTK_DATABOX (wg), i, plot.x_data, plot.y_data, color, GTK_DATABOX_GRID, 1);
 	gtk_databox_data_set_grid_config (GTK_DATABOX (wg), index, 9, 10);
 
 	/*
