@@ -1,6 +1,6 @@
 /**************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                               */
-/*  Copyright (C) 2005 - 2007  Felipe Castro                              */
+/*  Copyright (C) 2005 - 2008  Felipe Castro                              */
 /*                                                                        */
 /*  This program is free software, licensed under the terms of the GNU    */
 /*  General Public License as published by the Free Software Foundation,  */
@@ -42,8 +42,7 @@ trans_set_language_env (gchar * code)
 {
 	if (g_setenv ("LANGUAGE", code, 1) == FALSE)
 		if (g_setenv ("LANG", code, 1) == FALSE)
-			g_warning
-				("no language environment variable could be set.");
+			g_warning ("no language environment variable could be set.");
 	main_preferences_set_string ("interface", "language", code);
 	gtk_set_locale ();
 }
@@ -149,8 +148,7 @@ trans_init_language_env ()
 	 * If the language is already set in preferences, just use it
 	 */
 	if (main_preferences_exist ("interface", "language"))
-		tmp_code =
-			main_preferences_get_string ("interface", "language");
+		tmp_code = main_preferences_get_string ("interface", "language");
 	else
 	{
 		/* 
@@ -162,21 +160,22 @@ trans_init_language_env ()
 		while ((tmp_code = g_strdup (g_get_language_names ()[i])))
 		{
 			lang_ok = trans_lang_is_available (tmp_code);
-			if (lang_ok == TRUE)
+			if (lang_ok == TRUE && strlen (tmp_code) != 1)
 				break;
 			g_free (tmp_code);
+			lang_ok = FALSE;
 			i++;
 		}
 		if (lang_ok == FALSE)
 		{
 			i = 0;
-			while ((tmp_code =
-				g_strdup (g_get_language_names ()[i])))
+			while ((tmp_code = g_strdup (g_get_language_names ()[i])))
 			{
 				lang_ok = trans_lang_get_similar (tmp_code);
-				if (lang_ok == TRUE)
+				if (lang_ok == TRUE && strlen (tmp_code) != 1)
 					break;
 				g_free (tmp_code);
+				lang_ok = FALSE;
 				i++;
 			}
 		}
@@ -189,18 +188,17 @@ trans_init_language_env ()
 #endif
 	}
 	if (tmp_code == NULL)
-		tmp_code = g_strdup ("00");
+		tmp_code = g_strdup ("xx");
 	/*
 	 * If even a similar is not available, then use the neutral international one
 	 */
 	if (lang_ok == FALSE)
 	{
-		g_message ("as the locale \"%s\" isn't available,", tmp_code);
+		g_message ("as your prefered locale isn't available,");
 		g_free (tmp_code);
-		tmp_code = g_strdup ("eo_EO");
+		tmp_code = g_strdup ("eo");
 		g_message ("we are using this another one: \"%s\"", tmp_code);
-		g_message
-			("if you don't agree, try to change it at the main menu... :-)");
+		g_message ("if you don't agree, try to change it at the main menu... :-)");
 	}
 
 	trans_set_language_env (tmp_code);
@@ -220,12 +218,17 @@ trans_set_combo_language ()
 	GtkWidget *wg;
 
 	tmp_code = main_preferences_get_string ("interface", "language");
+	if (strcmp (tmp_code, "eo_XX") == 0)
+	{
+		main_preferences_set_string ("interface", "language", "eo");
+		g_free (tmp_code);
+		tmp_code = g_strdup ("eo");
+	}
 
 	for (i = 0, i_env = -1; i < lang_num; i++)
 	{
 		if (strcmp (lang[i].code, tmp_code) != 0)
-			languages =
-				g_list_insert (languages, lang[i].name, -1);
+			languages = g_list_insert (languages, lang[i].name, -1);
 		else
 			i_env = i;
 	}
@@ -262,9 +265,7 @@ trans_change_language ()
 
 	if (i == lang_num)
 	{
-		g_warning
-			("change_language() --> couldn't find the language: %s",
-			 selection);
+		g_warning ("change_language() --> couldn't find the language: %s", selection);
 		g_free (selection);
 		return;
 	}
@@ -303,13 +304,10 @@ trans_lang_get_similar_file (const gchar * file_end)
 	{
 		if (strcmp (lang[i].code, tmp_code) == 0)
 			continue;
-		if (lang[i].code[0] == tmp_code[0]
-		    && lang[i].code[1] == tmp_code[1])
+		if (lang[i].code[0] == tmp_code[0] && lang[i].code[1] == tmp_code[1])
 		{
 			g_free (tmp_path);
-			tmp_path =
-				g_strconcat (main_get_data_path (),
-					     lang[i].code, file_end, NULL);
+			tmp_path = g_strconcat (main_get_data_path (), lang[i].code, file_end, NULL);
 			fh = (FILE *) g_fopen (tmp_path, "r");
 		}
 	}
@@ -317,8 +315,7 @@ trans_lang_get_similar_file (const gchar * file_end)
 	g_free (tmp_path);
 	i--;
 	if (fh)
-		g_message ("applying similar file: %s%s", lang[i].code,
-			   file_end);
+		g_message ("applying similar file: %s%s", lang[i].code, file_end);
 	return (fh);
 }
 
@@ -353,8 +350,7 @@ trans_read_text (gchar * text, gint max_text_len, const gchar * file_end)
 	if (fh == NULL)
 	{
 		g_free (tmp_path);
-		tmp_path =
-			g_strconcat (main_get_data_path (), tmp_name, NULL);
+		tmp_path = g_strconcat (main_get_data_path (), tmp_name, NULL);
 		fh = (FILE *) g_fopen (tmp_path, "r");
 	}
 
@@ -371,12 +367,10 @@ trans_read_text (gchar * text, gint max_text_len, const gchar * file_end)
 	{
 		g_message
 			("trans_read_text() --> couldn't open the data file: %s\n"
-			 " So, we have to apply the default one: C%s",
-			 tmp_name, file_end);
+			 " So, we have to apply the default one: C%s", tmp_name, file_end);
 		main_preferences_set_string ("interface", "language", "C");
 		trans_read_text (text, max_text_len, file_end);
-		main_preferences_set_string ("interface", "language",
-					     tmp_code);
+		main_preferences_set_string ("interface", "language", tmp_code);
 		g_free (tmp_code);
 		g_free (tmp_path);
 		g_free (tmp_name);
