@@ -1,6 +1,6 @@
 /**************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                               */
-/*  Copyright (C) 2005 - 2007  Felipe Castro                              */
+/*  Copyright (C) 2005 - 2008  Felipe Castro                              */
 /*                                                                        */
 /*  This program is free software, licensed under the terms of the GNU    */
 /*  General Public License as published by the Free Software Foundation,  */
@@ -117,63 +117,35 @@ tutor_init (TutorType tt_type)
    */
 	if (tutor.type == TT_BASIC || tutor.type == TT_FLUID)
 	{
-		gtk_widget_show (lookup_widget
-				 (window_tutor_, "frame_lesson"));
-		gtk_widget_show (lookup_widget
-				 (window_tutor_, "vseparator_tutor"));
+		gtk_widget_show (lookup_widget (window_tutor_, "frame_lesson"));
+		gtk_widget_show (lookup_widget (window_tutor_, "vseparator_tutor"));
 		if (tutor.type == TT_BASIC)
 		{
-			gtk_widget_show (lookup_widget
-					 (window_tutor_,
-					  "button_revert_lesson"));
-			gtk_widget_show (lookup_widget
-					 (window_tutor_,
-					  "button_reset_lesson"));
-			gtk_widget_show (lookup_widget
-					 (window_tutor_,
-					  "button_tutor_show_keyb"));
-			gtk_label_set_text (GTK_LABEL
-					    (lookup_widget
-					     (window_tutor_, "label_lesson")),
-					    _("Lesson:"));
+			gtk_widget_show (lookup_widget (window_tutor_, "button_revert_lesson"));
+			gtk_widget_show (lookup_widget (window_tutor_, "button_reset_lesson"));
+			gtk_widget_show (lookup_widget (window_tutor_, "button_tutor_show_keyb"));
+			gtk_label_set_text (GTK_LABEL (lookup_widget (window_tutor_, "label_lesson")), _("Lesson:"));
 			gtk_spin_button_set_range (GTK_SPIN_BUTTON
-						   (lookup_widget
-						    (window_tutor_,
-						     "spinbutton_lesson")), 1,
-						   50);
+						   (lookup_widget (window_tutor_, "spinbutton_lesson")), 1, 50);
 		}
 		else
 		{
-			gtk_widget_hide (lookup_widget
-					 (window_tutor_,
-					  "button_revert_lesson"));
-			gtk_widget_hide (lookup_widget
-					 (window_tutor_,
-					  "button_reset_lesson"));
-			gtk_widget_hide (lookup_widget
-					 (window_tutor_,
-					  "button_tutor_show_keyb"));
+			gtk_widget_hide (lookup_widget (window_tutor_, "button_revert_lesson"));
+			gtk_widget_hide (lookup_widget (window_tutor_, "button_reset_lesson"));
+			gtk_widget_hide (lookup_widget (window_tutor_, "button_tutor_show_keyb"));
 			gtk_label_set_text (GTK_LABEL
-					    (lookup_widget
-					     (window_tutor_, "label_lesson")),
-					    _("Paragraphs:"));
+					    (lookup_widget (window_tutor_, "label_lesson")), _("Paragraphs:"));
 			callbacks_shield = TRUE;
 			gtk_spin_button_set_range (GTK_SPIN_BUTTON
-						   (lookup_widget
-						    (window_tutor_,
-						     "spinbutton_lesson")), 1,
-						   10);
+						   (lookup_widget (window_tutor_, "spinbutton_lesson")), 1, 10);
 			callbacks_shield = FALSE;
 		}
 	}
 	else
 	{
-		gtk_widget_hide (lookup_widget
-				 (window_tutor_, "frame_lesson"));
-		gtk_widget_hide (lookup_widget
-				 (window_tutor_, "vseparator_tutor"));
-		gtk_widget_hide (lookup_widget
-				 (window_tutor_, "button_tutor_show_keyb"));
+		gtk_widget_hide (lookup_widget (window_tutor_, "frame_lesson"));
+		gtk_widget_hide (lookup_widget (window_tutor_, "vseparator_tutor"));
+		gtk_widget_hide (lookup_widget (window_tutor_, "button_tutor_show_keyb"));
 		basic_set_lesson (0);
 	}
 
@@ -203,16 +175,12 @@ tutor_init (TutorType tt_type)
 
 	case TT_VELO:
 		tmp_title = g_strdup (_("Klavaro - Velocity"));
-		tmp_name =
-			g_strdup (_
-				  ("Velocity exercises: accelerate typing real words."));
+		tmp_name = g_strdup (_("Velocity exercises: accelerate typing real words."));
 		break;
 
 	case TT_FLUID:
 		tmp_title = g_strdup (_("Klavaro - Fluidness"));
-		tmp_name =
-			g_strdup (_
-				  ("Fluidness exercises: accuracy typing good sense paragraphs."));
+		tmp_name = g_strdup (_("Fluidness exercises: accuracy typing good sense paragraphs."));
 		break;
 	}
 	gtk_window_set_title (GTK_WINDOW (window_tutor_), tmp_title);
@@ -259,25 +227,17 @@ tutor_update ()
 
 	case QUERY_PROCESS_TOUCHS:
 		tutor_message (_("STARTED! => "));
-		gtk_widget_show (lookup_widget
-				 (window_tutor_, "button_tutor_restart"));
-		gtk_widget_set_sensitive (lookup_widget
-					  (window_tutor_,
-					   "button_tutor_font"), TRUE);
+		gtk_widget_show (lookup_widget (window_tutor_, "button_tutor_restart"));
+		gtk_widget_set_sensitive (lookup_widget (window_tutor_, "button_tutor_font"), TRUE);
 		break;
 
 	case QUERY_END:
 		if (tutor.type == TT_BASIC)
-			tutor_message (_("<<==  End of lesson."
-					 " Press [Enter] to start another. ==>> "));
+			tutor_message (_("<<==  End of lesson." " Press [Enter] to start another. ==>> "));
 		else
-			tutor_message (_("<<==  End of exercise."
-					 " Press [Enter] to start another. ==>> "));
-		gtk_widget_hide (lookup_widget
-				 (window_tutor_, "button_tutor_restart"));
-		gtk_widget_set_sensitive (lookup_widget
-					  (window_tutor_,
-					   "button_tutor_font"), FALSE);
+			tutor_message (_("<<==  End of exercise." " Press [Enter] to start another. ==>> "));
+		gtk_widget_hide (lookup_widget (window_tutor_, "button_tutor_restart"));
+		gtk_widget_set_sensitive (lookup_widget (window_tutor_, "button_tutor_font"), FALSE);
 		break;
 	}
 }
@@ -296,45 +256,31 @@ tutor_update_intro ()
 	{
 		callbacks_shield = TRUE;
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON
-					   (lookup_widget
-					    (window_tutor_,
-					     "spinbutton_lesson")),
-					   basic_get_lesson ());
+					   (lookup_widget (window_tutor_, "spinbutton_lesson")), basic_get_lesson ());
 		callbacks_shield = FALSE;
 
-		wg_label =
-			GTK_LABEL (lookup_widget
-				   (window_tutor_, "label_heading"));
-		gtk_label_set_text (wg_label,
-				    _("Learning the key positions."));
+		wg_label = GTK_LABEL (lookup_widget (window_tutor_, "label_heading"));
+		gtk_label_set_text (wg_label, _("Learning the key positions."));
 		tutor_message (_("Press any key to start the lesson. "));
 	}
 	else
 		tutor_message (_("Press any key to start the exercise. "));
 
-	gtk_widget_hide (lookup_widget
-			 (window_tutor_, "button_tutor_restart"));
-	gtk_widget_set_sensitive (lookup_widget
-				  (window_tutor_, "button_tutor_font"),
-				  FALSE);
+	gtk_widget_hide (lookup_widget (window_tutor_, "button_tutor_restart"));
+	gtk_widget_set_sensitive (lookup_widget (window_tutor_, "button_tutor_font"), FALSE);
 
-	tmp_name =
-		g_strconcat ("_", tutor_get_type_name (), "_intro.txt", NULL);
+	tmp_name = g_strconcat ("_", tutor_get_type_name (), "_intro.txt", NULL);
 	trans_read_text (text, 4096, tmp_name);
 	g_free (tmp_name);
 	wg_text = GTK_TEXT_VIEW (lookup_widget (window_tutor_, "text_tutor"));
-	gtk_text_buffer_set_text (gtk_text_view_get_buffer (wg_text), text,
-				  -1);
+	gtk_text_buffer_set_text (gtk_text_view_get_buffer (wg_text), text, -1);
 
 	callbacks_shield = TRUE;
-	gtk_entry_set_text (GTK_ENTRY
-			    (lookup_widget (window_tutor_, "entry_mesg")),
-			    "");
+	gtk_entry_set_text (GTK_ENTRY (lookup_widget (window_tutor_, "entry_mesg")), "");
 	callbacks_shield = FALSE;
 
 	wg = lookup_widget (window_tutor_, "scrolledwindow_tutor_main");
-	scroll = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW
-						      (wg));
+	scroll = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (wg));
 	gtk_adjustment_set_value (scroll, 0);
 }
 
@@ -342,7 +288,7 @@ void
 tutor_update_start ()
 {
 	gchar *tmp_name;
-	gchar text[200];
+	gchar *text;
 	gint level;
 	GtkWidget *wg;
 	GtkTextBuffer *buf;
@@ -361,24 +307,19 @@ tutor_update_start ()
 	{
 		callbacks_shield = TRUE;
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (lookup_widget
-							    (window_tutor_,
-							     "spinbutton_lesson")),
-					   basic_get_lesson ());
+							    (window_tutor_, "spinbutton_lesson")), basic_get_lesson ());
 		callbacks_shield = FALSE;
 
 		if (main_preferences_exist ("tutor", "basic_lesson"))
 		{
-			level = main_preferences_get_int ("tutor",
-							  "basic_lesson");
-			wg = lookup_widget (window_tutor_,
-					    "button_revert_lesson");
+			level = main_preferences_get_int ("tutor", "basic_lesson");
+			wg = lookup_widget (window_tutor_, "button_revert_lesson");
 			if (level == basic_get_lesson ())
 				gtk_widget_hide (wg);
 			else
 				gtk_widget_show (wg);
 
-			wg = lookup_widget (window_tutor_,
-					    "button_reset_lesson");
+			wg = lookup_widget (window_tutor_, "button_reset_lesson");
 			if (level == 1)
 				gtk_widget_hide (wg);
 			else
@@ -386,18 +327,16 @@ tutor_update_start ()
 		}
 		else
 		{
-			wg = lookup_widget (window_tutor_,
-					    "button_revert_lesson");
+			wg = lookup_widget (window_tutor_, "button_revert_lesson");
 			gtk_widget_show (wg);
 		}
 
-		tmp_name =
-			g_ucs4_to_utf8 (basic_get_char_set (), -1, NULL, NULL,
-					NULL);
-		sprintf (text, _("Keys: %s"), tmp_name);
+		tmp_name = g_ucs4_to_utf8 (basic_get_char_set (), -1, NULL, NULL, NULL);
+		text = g_strdup_printf (_("Keys: %s"), tmp_name);
 		g_free (tmp_name);
 		wg = lookup_widget (window_tutor_, "label_heading");
 		gtk_label_set_text (GTK_LABEL (wg), text);
+		g_free (text);
 		basic_draw_lesson ();
 	}
 
@@ -420,24 +359,18 @@ tutor_update_start ()
 	 */
 	gtk_text_buffer_get_bounds (buf, &start, &end);
 	gtk_text_iter_backward_char (&end);
-	gtk_text_buffer_apply_tag_by_name (buf, "char_untouched", &start,
-					   &end);
+	gtk_text_buffer_apply_tag_by_name (buf, "char_untouched", &start, &end);
 	gtk_text_buffer_apply_tag_by_name (buf, "lesson_font", &start, &end);
 
-	gtk_widget_hide (lookup_widget
-			 (window_tutor_, "button_tutor_restart"));
-	gtk_widget_set_sensitive (lookup_widget
-				  (window_tutor_, "button_tutor_font"), TRUE);
+	gtk_widget_hide (lookup_widget (window_tutor_, "button_tutor_restart"));
+	gtk_widget_set_sensitive (lookup_widget (window_tutor_, "button_tutor_font"), TRUE);
 	tutor_message (_("Start typing when you are ready. "));
 	callbacks_shield = TRUE;
-	gtk_entry_set_text (GTK_ENTRY
-			    (lookup_widget (window_tutor_, "entry_mesg")),
-			    "");
+	gtk_entry_set_text (GTK_ENTRY (lookup_widget (window_tutor_, "entry_mesg")), "");
 	callbacks_shield = FALSE;
 
 	wg = lookup_widget (window_tutor_, "scrolledwindow_tutor_main");
-	scroll = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW
-						      (wg));
+	scroll = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (wg));
 	gtk_adjustment_set_value (scroll, 0);
 }
 
@@ -475,8 +408,7 @@ tutor_process_touch (gunichar user_chr)
 		{
 			cursor_set_blink (FALSE);
 			cursor_set_is_initializing (TRUE);
-			g_timeout_add (TIME_CURSOR_ON + TIME_CURSOR_OFF + 30,
-				       &cursor_init, NULL);
+			g_timeout_add (TIME_CURSOR_ON + TIME_CURSOR_OFF + 30, &cursor_init, NULL);
 		}
 		if (tutor.type == TT_BASIC)
 			hints_update_from_char (cursor_get_char ());
@@ -499,6 +431,7 @@ tutor_process_touch (gunichar user_chr)
 	case QUERY_END:
 		if (user_chr == UPSYM)
 		{
+			basic_set_lesson_increased (FALSE);
 			tutor.query = QUERY_INTRO;
 			tutor_process_touch (L'\0');
 		}
@@ -596,8 +529,7 @@ tutor_eval_forward_backward (gunichar user_chr)
 	 */
 	if (user_chr == L'\b' || user_chr == L'\t')
 	{
-		tutor.touch_time[tutor.ttidx] =
-			g_timer_elapsed (tutor.tmr, NULL);
+		tutor.touch_time[tutor.ttidx] = g_timer_elapsed (tutor.tmr, NULL);
 
 		/*
 		 * Test for end of errors to be corrected
@@ -654,11 +586,9 @@ tutor_eval_forward_backward (gunichar user_chr)
 		if (tutor.ttidx < MAX_TOUCH_TICS)
 		{
 			tutor.touch_time[tutor.ttidx] =
-				g_timer_elapsed (tutor.tmr, NULL) -
-				tutor.touch_time[tutor.ttidx];
+				g_timer_elapsed (tutor.tmr, NULL) - tutor.touch_time[tutor.ttidx];
 			tutor.ttidx++;
-			tutor.touch_time[tutor.ttidx] =
-				g_timer_elapsed (tutor.tmr, NULL);
+			tutor.touch_time[tutor.ttidx] = g_timer_elapsed (tutor.tmr, NULL);
 		}
 		if (tutor.correcting != 0)
 		{
@@ -670,8 +600,7 @@ tutor_eval_forward_backward (gunichar user_chr)
 	}
 	else
 	{
-		tutor.touch_time[tutor.ttidx] =
-			g_timer_elapsed (tutor.tmr, NULL);
+		tutor.touch_time[tutor.ttidx] = g_timer_elapsed (tutor.tmr, NULL);
 		cursor_paint_char ("char_wrong");
 		tutor_beep ();
 		tutor.retro_pos++;
@@ -720,8 +649,8 @@ tutor_calc_stats ()
 	gdouble average = 0;
 	gdouble sample;
 	gchar *tmp_locale;
-	gchar str[200];
 	gchar *tmp_str = NULL;
+	gchar *tmp_str2;
 	gchar *tmp_name;
 	FILE *fh;
 	time_t tmp_time;
@@ -736,8 +665,7 @@ tutor_calc_stats ()
 	seconds = ((gulong) tutor.elapsed_time) % 60;
 
 	accuracy = 100 * (1.0 - (gfloat) tutor.n_errors / tutor.n_touchs);
-	touchs_per_second =
-		(tutor.n_touchs - tutor.n_errors) / tutor.elapsed_time;
+	touchs_per_second = (tutor.n_touchs - tutor.n_errors) / tutor.elapsed_time;
 	velocity = 10 * touchs_per_second;
 
 	if (tutor.type == TT_FLUID)
@@ -780,19 +708,18 @@ tutor_calc_stats ()
 	 * Changing to "C" locale: remember to copy the previous value!
 	 */
 	tmp_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
-	setlocale (LC_NUMERIC, "C");
+	if (tmp_locale != NULL)
+		setlocale (LC_NUMERIC, "C");
 
 	/*
 	 * Logging
 	 */
-	tmp_name = g_strconcat (main_get_user_dir (), "stat_",
-				tutor_get_type_name (), ".txt", NULL);
+	tmp_name = g_strconcat (main_get_user_dir (), "stat_", tutor_get_type_name (), ".txt", NULL);
 	assert_user_dir ();
 	if (!(fh = (FILE *) g_fopen (tmp_name, "r")))
 	{
 		fh = (FILE *) g_fopen (tmp_name, "w");
-		fprintf (fh,
-			 "Accuracy\tVelocity\tFluidness\tDate\tHour\tLesson\n");
+		fprintf (fh, "Accuracy\tVelocity\tFluidness\tDate\tHour\tLesson\n");
 	}
 	else
 	{
@@ -833,33 +760,28 @@ tutor_calc_stats ()
 		/*
 		 * Logging the fluidness results of the last session
 		 */
-		tmp_name =
-			g_strconcat (main_get_user_dir (),
-				     "deviation_fluid.txt", NULL);
+		tmp_name = g_strconcat (main_get_user_dir (), "deviation_fluid.txt", NULL);
 		if ((fh = (FILE *) g_fopen (tmp_name, "w")))
 		{
-			g_message
-				("writing further fluidness results at:\n %s",
-				 tmp_name);
+			g_message ("writing further fluidness results at:\n %s", tmp_name);
 			fprintf (fh,
 				 "(i)\tdt(i)\tsqrt(1/dt(i))\tAverage:\t%g\tStd. dev.:\t%g\n",
 				 average, standard_deviation);
 			for (i = 1; i < tutor.ttidx; i++)
-				fprintf (fh, "%i\t%g\t%g\n", i,
-					 tutor.touch_time[i],
-					 sqrt (1 / tutor.touch_time[i]));
+				fprintf (fh, "%i\t%g\t%g\n", i, tutor.touch_time[i],
+					 sqrt (1 / (tutor.touch_time[i] > 0 ? tutor.touch_time[i] : 1.0e-9)));
 			fclose (fh);
 		}
 		else
-			g_message ("not able to log on this file:\n %s",
-				   tmp_name);
+			g_message ("not able to log on this file:\n %s", tmp_name);
 		g_free (tmp_name);
 	}
 
 	/*
 	 * Coming back to the right locale
 	 */
-	setlocale (LC_NUMERIC, tmp_locale);
+	if (tmp_locale != NULL)
+		setlocale (LC_NUMERIC, tmp_locale);
 	g_free (tmp_locale);
 
 	/*
@@ -874,8 +796,7 @@ tutor_calc_stats ()
 				       " %i ", dngettext (PACKAGE, "second",
 							  "seconds", seconds),
 				       "\n", _("Accuracy:"), " %.1f %%\t\t",
-				       _("Goal:"), " %i %%\n\n",
-				       _("Comments:"), "\n", NULL);
+				       _("Goal:"), " %i %%\n\n", _("Comments:"), "\n", NULL);
 	}
 
 	wg = lookup_widget (window_tutor_, "text_tutor");
@@ -884,13 +805,13 @@ tutor_calc_stats ()
 	switch (tutor.type)
 	{
 	case TT_BASIC:
-		sprintf (str, tmp_str, minutes, seconds, accuracy, 95);
-		gtk_text_buffer_insert_at_cursor (buf, str, strlen (str));
+		tmp_str2 = g_strdup_printf (tmp_str, minutes, seconds, accuracy, 95);
+		gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
 		basic_comment (accuracy);
 		break;
 	case TT_ADAPT:
-		sprintf (str, tmp_str, minutes, seconds, accuracy, 99);
-		gtk_text_buffer_insert_at_cursor (buf, str, strlen (str));
+		tmp_str2 = g_strdup_printf (tmp_str, minutes, seconds, accuracy, 99);
+		gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
 		adapt_comment (accuracy);
 		break;
 	case TT_VELO:
@@ -906,11 +827,9 @@ tutor_calc_stats ()
 				       " %.2f\t\t", _("Goal:"), " %i ",
 				       _("(CPS)"), "\n",
 				       _("Words per minute:"), " %.1f\t\t",
-				       _("Goal:"), " %i ", _("(WPM)"), "\n\n",
-				       _("Comments:"), "\n", NULL);
-		sprintf (str, tmp_str, minutes, seconds, accuracy, 97,
-			 velocity / 10, 5, velocity, 50);
-		gtk_text_buffer_insert_at_cursor (buf, str, strlen (str));
+				       _("Goal:"), " %i ", _("(WPM)"), "\n\n", _("Comments:"), "\n", NULL);
+		tmp_str2 = g_strdup_printf (tmp_str, minutes, seconds, accuracy, 97, velocity / 10, 5, velocity, 50);
+		gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
 		velo_comment (accuracy, velocity);
 		break;
 	case TT_FLUID:
@@ -928,17 +847,17 @@ tutor_calc_stats ()
 				       _("Words per minute:"), " %.1f\t\t",
 				       _("Goal:"), " %i ", _("(WPM)"), "\n",
 				       _("Fluidness:"), " %.1f %%\t\t",
-				       _("Goal:"), " %i %%\n\n",
-				       _("Comments:"), "\n", NULL);
-		sprintf (str, tmp_str, minutes, seconds, accuracy, 98,
-			 velocity / 10, 5, velocity, 50, fluidness, 90);
-		gtk_text_buffer_insert_at_cursor (buf, str, strlen (str));
+				       _("Goal:"), " %i %%\n\n", _("Comments:"), "\n", NULL);
+		tmp_str2 =
+			g_strdup_printf (tmp_str, minutes, seconds, accuracy, 98, velocity / 10, 5, velocity, 50,
+					 fluidness, 90);
+		gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
 		fluid_comment (accuracy, velocity, fluidness);
 	}
 	g_free (tmp_str);
+	g_free (tmp_str2);
 
-	gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (wg),
-					    gtk_text_buffer_get_insert (buf));
+	gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (wg), gtk_text_buffer_get_insert (buf));
 }
 
 /**********************************************************************
@@ -958,8 +877,7 @@ tutor_draw_paragraph (gchar * utf8_text)
 
 	if (g_utf8_strrchr (utf8_text, -1, L'\n') == NULL)
 	{
-		g_message
-			("paragraph not terminated by carriage return: adding one.");
+		g_message ("paragraph not terminated by carriage return: adding one.");
 		tmp1 = g_strconcat (utf8_text, "\n", NULL);
 	}
 	else
@@ -974,8 +892,7 @@ tutor_draw_paragraph (gchar * utf8_text)
 	wg = lookup_widget (window_tutor_, "text_tutor");
 	buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (wg));
 
-	tmp2 = g_strconcat (tmp1, keyb_get_utf8_paragraph_symbol (), "\n",
-			    NULL);
+	tmp2 = g_strconcat (tmp1, keyb_get_utf8_paragraph_symbol (), "\n", NULL);
 
 	gtk_text_buffer_insert_at_cursor (buf, tmp2, -1);
 }
