@@ -1,6 +1,6 @@
 /**************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                               */
-/*  Copyright (C) 2005 - 2007  Felipe Castro                              */
+/*  Copyright (C) 2005 - 2008  Felipe Castro                              */
 /*                                                                        */
 /*  This program is free software, licensed under the terms of the GNU    */
 /*  General Public License as published by the Free Software Foundation,  */
@@ -69,12 +69,8 @@ velo_init ()
 	{
 		if (main_preferences_exist ("tutor", "word_list"))
 		{
-			wl_name =
-				main_preferences_get_string ("tutor",
-							     "word_list");
-			tmp_name =
-				g_strconcat (main_get_user_dir (), wl_name,
-					     ".words", NULL);
+			wl_name = main_preferences_get_string ("tutor", "word_list");
+			tmp_name = g_strconcat (main_get_user_dir (), wl_name, ".words", NULL);
 			if ((fh = (FILE *) g_fopen (tmp_name, "r")))
 			{
 				fclose (fh);
@@ -105,9 +101,7 @@ velo_init_dict (gchar * list_name)
 	if (list_name && strcmp (list_name, _("--> Default")) != 0)
 	{
 		main_preferences_set_string ("tutor", "word_list", list_name);
-		tmp_name =
-			g_strconcat (main_get_user_dir (), list_name,
-				     ".words", NULL);
+		tmp_name = g_strconcat (main_get_user_dir (), list_name, ".words", NULL);
 		g_message ("loading dictionary: %s.words", list_name);
 		strncpy (dict.name, list_name, 20);
 		dict.name[20] = '\0';
@@ -115,11 +109,8 @@ velo_init_dict (gchar * list_name)
 	else
 	{
 		main_preferences_remove ("tutor", "word_list");
-		tmp_code =
-			main_preferences_get_string ("interface", "language");
-		tmp_name =
-			g_strconcat (main_get_data_path (), tmp_code,
-				     ".words", NULL);
+		tmp_code = main_preferences_get_string ("interface", "language");
+		tmp_name = g_strconcat (main_get_data_path (), tmp_code, ".words", NULL);
 		g_message ("loading dictionary: %s.words", tmp_code);
 		strcpy (dict.name, "Default");
 		g_free (tmp_code);
@@ -141,9 +132,7 @@ velo_init_dict (gchar * list_name)
 		{
 			str_32[strlen (str_32) - 1] = '\0';
 			word_str = g_strconcat (word_str, " ", str_32, NULL);
-			dict.list =
-				g_list_append (dict.list,
-					       strrchr (word_str, ' ') + 1);
+			dict.list = g_list_append (dict.list, strrchr (word_str, ' ') + 1);
 			if (++nwords % 10 == 0)
 				g_print (" - %u", nwords / 10);
 		}
@@ -156,14 +145,12 @@ velo_init_dict (gchar * list_name)
 	{
 		g_message ("could not open the file: %s", tmp_name);
 		g_free (tmp_name);
-		tmp_code =
-			main_preferences_get_string ("interface", "language");
+		tmp_code = main_preferences_get_string ("interface", "language");
 		if (strcmp (tmp_code, "C") == 0)
 			g_error ("so, we must quit!");
 		main_preferences_set_string ("interface", "language", "C");
 		velo_init_dict (list_name);
-		main_preferences_set_string ("interface", "language",
-					     tmp_code);
+		main_preferences_set_string ("interface", "language", tmp_code);
 		g_free (tmp_code);
 		return;
 	}
@@ -236,8 +223,7 @@ velo_create_dict (gchar * file_name, gboolean overwrite)
 	if (file_name == NULL)
 	{
 		gdk_beep ();
-		g_warning
-			("velo_create_dict(): null file name as first argument.");
+		g_warning ("velo_create_dict(): null file name as first argument.");
 		return;
 	}
 
@@ -249,9 +235,7 @@ velo_create_dict (gchar * file_name, gboolean overwrite)
 	}
 
 	dictio_name = g_strdup (strrchr (file_name, DIRSEP) + 1);
-	dict_path =
-		g_strconcat (main_get_user_dir (), dictio_name, ".words",
-			     NULL);
+	dict_path = g_strconcat (main_get_user_dir (), dictio_name, ".words", NULL);
 
 	assert_user_dir ();
 	if (!(fh_destiny = (FILE *) g_fopen (dict_path, "w")))
@@ -274,24 +258,24 @@ velo_create_dict (gchar * file_name, gboolean overwrite)
 	i = 0;
 	nlin = 0;
 	nwords = 0;
-	g_print ("Processing file:\n %s\nParagraph:\n0", file_name);
+	//g_print ("Processing file:\n %s\nParagraph:\n0", file_name);
 	while (fgets (tmp_str, MAX_LINE_LEN, fh_source) != NULL)
 	{
 		if (nlin++ > MAX_LINES)
 		{
-			g_print (" - truncated!");
+			//g_print (" - truncated!");
 			break;
 		}
 		g_print (" - %u", nlin);
 
 		if (g_utf8_validate (tmp_str, -1, NULL) == FALSE)
 		{
-			g_print (": NOT UTF8!");
+			//g_print (": NOT UTF8!");
 			continue;
 		}
 		if (strcmp (tmp_str, "\n") == 0)
 		{
-			g_print (": BLANK!");
+			//g_print (": BLANK!");
 			continue;
 		}
 
@@ -313,10 +297,7 @@ velo_create_dict (gchar * file_name, gboolean overwrite)
 				if (i > 1)
 				{
 					nwords++;
-					tmp_utf8_word =
-						g_ucs4_to_utf8 (tmp_uniword,
-								i, NULL, NULL,
-								NULL);
+					tmp_utf8_word = g_ucs4_to_utf8 (tmp_uniword, i, NULL, NULL, NULL);
 					fputs (tmp_utf8_word, fh_destiny);
 					fputc ('\n', fh_destiny);
 					g_free (tmp_utf8_word);
@@ -336,7 +317,7 @@ velo_create_dict (gchar * file_name, gboolean overwrite)
 	fclose (fh_source);
 	fclose (fh_destiny);
 
-	g_print ("- end.\n");
+	//g_print ("- end.\n");
 
 	if (overwrite == TRUE)
 	{
@@ -353,7 +334,7 @@ velo_create_dict (gchar * file_name, gboolean overwrite)
 void
 velo_comment (gdouble accuracy, gdouble velocity)
 {
-	gchar str[1000];
+	gchar *tmp_str;
 	GtkWidget *wg;
 	GtkTextBuffer *buf;
 
@@ -361,53 +342,35 @@ velo_comment (gdouble accuracy, gdouble velocity)
 	 * Comments
 	 */
 	if (accuracy < 97)
-		sprintf (str,
-			 _(" Your accuracy rate is too low.\n"
-			   " I only can rely on you if it is greater than 97 %%.\n"
-			   " Please do it again.\n"));
+		tmp_str = g_strdup (_(" Your accuracy rate is too low.\n"
+				      " I only can rely on you if it is greater than 97 %%.\n Please do it again.\n"));
 	else if (velocity < 10)
-		sprintf (str,
-			 _(" You must be kidding. You are so slow!\n"
-			   " Please do it again and again.\n"));
+		tmp_str = g_strdup (_(" You must be kidding. You are so slow!\n Please do it again and again.\n"));
 	else if (velocity < 20)
-		sprintf (str,
-			 _
-			 (" Still away from the highway. You can make better...\n"
-			  " Try at least 20 WPM.\n"));
+		tmp_str = g_strdup (_(" Still away from the highway. You can make better...\n Try at least 20 WPM.\n"));
 	else if (velocity < 30)
-		sprintf (str,
-			 _(" You are doing well, but need to go faster.\n"
-			   " And don't forget the accuracy. Try to get 30 WPM.\n"));
+		tmp_str = g_strdup (_(" You are doing well, but need to go faster.\n"
+				      " And don't forget the accuracy. Try to get 30 WPM.\n"));
 	else if (velocity < 40)
-		sprintf (str,
-			 _(" Fine. Now you need to start running.\n"
-			   " Can you reach 40 WPM?\n"));
+		tmp_str = g_strdup (_(" Fine. Now you need to start running.\n Can you reach 40 WPM?\n"));
 	else if (velocity < 50)
-		sprintf (str, _(" Very good. You are almost there.\n"
-				" Can you finally reach 50 WPM?\n"));
+		tmp_str = g_strdup (_(" Very good. You are almost there.\n Can you finally reach 50 WPM?\n"));
 	else if (velocity < 60)
-		sprintf (str,
-			 _(" Excellent. For this course, that is enough.\n"
-			   " Try now the fluidness exercises, OK?\n"));
+		tmp_str =
+			g_strdup (_
+				  (" Excellent. For this course, that is enough.\n Try now the fluidness exercises, OK?\n"));
 	else if (velocity < 70)
-		sprintf (str,
-			 _(" Fast! Are you training for a competition?\n"
-			   " So, try to get 70 WPM!\n"));
+		tmp_str = g_strdup (_(" Fast! Are you training for a competition?\n So, try to get 70 WPM!\n"));
 	else if (velocity < 80)
-		sprintf (str,
-			 _(" Top of \"qwerty\"."
-			   " Now it's time to change to the Dvorak mode.\n"
-			   " Are you afraid of reaching 80 WPM?\n"));
+		tmp_str = g_strdup (_(" Top of \"qwerty\"."
+				      " Now it's time to change to the Dvorak mode.\n Are you afraid of reaching 80 WPM?\n"));
 	else if (velocity < 90)
-		sprintf (str,
-			 _(" Dvorak mode dominated!\n"
-			   " Can you fly at 90 WPM?\n"));
+		tmp_str = g_strdup (_(" Dvorak mode dominated!\n Can you fly at 90 WPM?\n"));
 	else
-		sprintf (str,
-			 _(" Dvorak master!\n"
-			   " I have no words to express my admiration!\n"));
+		tmp_str = g_strdup (_(" Dvorak master!\n" " I have no words to express my admiration!\n"));
 
 	wg = lookup_widget (window_tutor_, "text_tutor");
 	buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (wg));
-	gtk_text_buffer_insert_at_cursor (buf, str, strlen (str));
+	gtk_text_buffer_insert_at_cursor (buf, tmp_str, strlen (tmp_str));
+	g_free (tmp_str);
 }
